# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/web/server_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.api import httpbody_pb2 as yamcs_dot_api_dot_httpbody__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/web/server_service.proto',
  package='yamcs.protobuf.web',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\022ServerServiceProtoP\001'),
  serialized_pb=_b('\n\'yamcs/protobuf/web/server_service.proto\x12\x12yamcs.protobuf.web\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a\x18yamcs/api/httpbody.proto\"\x1e\n\x10GetThreadRequest\x12\n\n\x02id\x18\x01 \x01(\x03\"F\n\x13ListThreadsResponse\x12/\n\x07threads\x18\x01 \x03(\x0b\x32\x1e.yamcs.protobuf.web.ThreadInfo\"C\n\x12ListRoutesResponse\x12-\n\x06routes\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.web.RouteInfo\"C\n\x12ListTopicsResponse\x12-\n\x06topics\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.web.TopicInfo\"\xa6\x01\n\x0bHttpTraffic\x12\x11\n\treadBytes\x18\x01 \x01(\x04\x12\x14\n\x0cwrittenBytes\x18\x02 \x01(\x04\x12\x16\n\x0ereadThroughput\x18\x03 \x01(\x04\x12\x17\n\x0fwriteThroughput\x18\x04 \x01(\x04\x12=\n\x0b\x63onnections\x18\x05 \x03(\x0b\x32(.yamcs.protobuf.web.ClientConnectionInfo\"\xda\x01\n\tRouteInfo\x12\x0f\n\x07service\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nhttpMethod\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12\x11\n\tinputType\x18\x06 \x01(\t\x12\x12\n\noutputType\x18\x07 \x01(\t\x12\x12\n\ndeprecated\x18\x08 \x01(\x08\x12\x14\n\x0crequestCount\x18\t \x01(\x03\x12\x12\n\nerrorCount\x18\n \x01(\x03\x12\x11\n\tlogFormat\x18\x0b \x01(\t\"\x8b\x01\n\tTopicInfo\x12\r\n\x05topic\x18\x01 \x01(\t\x12\x0f\n\x07service\x18\x02 \x01(\t\x12\x0e\n\x06method\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tinputType\x18\x05 \x01(\t\x12\x12\n\noutputType\x18\x06 \x01(\t\x12\x12\n\ndeprecated\x18\x07 \x01(\x08\"_\n\x10TraceElementInfo\x12\x11\n\tclassName\x18\x01 \x01(\t\x12\x10\n\x08\x66ileName\x18\x02 \x01(\t\x12\x12\n\nmethodName\x18\x03 \x01(\t\x12\x12\n\nlineNumber\x18\x04 \x01(\x05\"#\n\x12ListThreadsRequest\x12\r\n\x05\x64\x65pth\x18\x01 \x01(\x05\"d\n\x0fThreadGroupInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x61\x65mon\x18\x02 \x01(\x08\x12\x33\n\x06parent\x18\x03 \x01(\x0b\x32#.yamcs.protobuf.web.ThreadGroupInfo\"\xc1\x01\n\nThreadInfo\x12\n\n\x02id\x18\x01 \x01(\x03\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05state\x18\x03 \x01(\t\x12\x0e\n\x06native\x18\x04 \x01(\x08\x12\x11\n\tsuspended\x18\x05 \x01(\x08\x12\x32\n\x05group\x18\x06 \x01(\x0b\x32#.yamcs.protobuf.web.ThreadGroupInfo\x12\x33\n\x05trace\x18\x07 \x03(\x0b\x32$.yamcs.protobuf.web.TraceElementInfo\"\xaf\x03\n\x15GetServerInfoResponse\x12\x14\n\x0cyamcsVersion\x18\x01 \x01(\t\x12\x10\n\x08revision\x18\x06 \x01(\t\x12\x10\n\x08serverId\x18\x02 \x01(\t\x12\x1c\n\x14\x64\x65\x66\x61ultYamcsInstance\x18\x03 \x01(\t\x12\x45\n\x07plugins\x18\x05 \x03(\x0b\x32\x34.yamcs.protobuf.web.GetServerInfoResponse.PluginInfo\x12S\n\x0e\x63ommandOptions\x18\x07 \x03(\x0b\x32;.yamcs.protobuf.web.GetServerInfoResponse.CommandOptionInfo\x1aP\n\nPluginInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x0e\n\x06vendor\x18\x04 \x01(\t\x1aP\n\x11\x43ommandOptionInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bverboseName\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x0c\n\x04help\x18\x04 \x01(\t\"\x8c\x03\n\x14\x43lientConnectionInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04open\x18\x02 \x01(\x08\x12\x0e\n\x06\x61\x63tive\x18\x03 \x01(\x08\x12\x10\n\x08writable\x18\x04 \x01(\x08\x12\x15\n\rremoteAddress\x18\x05 \x01(\t\x12\x11\n\treadBytes\x18\x06 \x01(\x04\x12\x14\n\x0cwrittenBytes\x18\x07 \x01(\x04\x12\x16\n\x0ereadThroughput\x18\x08 \x01(\x04\x12\x17\n\x0fwriteThroughput\x18\t \x01(\x04\x12M\n\x0bhttpRequest\x18\n \x01(\x0b\x32\x38.yamcs.protobuf.web.ClientConnectionInfo.HttpRequestInfo\x12\x10\n\x08username\x18\x0b \x01(\t\x1a\x66\n\x0fHttpRequestInfo\x12\x10\n\x08protocol\x18\x01 \x01(\t\x12\x0e\n\x06method\x18\x02 \x01(\t\x12\x0b\n\x03uri\x18\x03 \x01(\t\x12\x11\n\tkeepAlive\x18\x04 \x01(\x08\x12\x11\n\tuserAgent\x18\x05 \x01(\t2\xc6\x05\n\tServerApi\x12^\n\rGetServerInfo\x12\x16.google.protobuf.Empty\x1a).yamcs.protobuf.web.GetServerInfoResponse\"\n\x8a\x92\x03\x06\n\x04/api\x12_\n\nListRoutes\x12\x16.google.protobuf.Empty\x1a&.yamcs.protobuf.web.ListRoutesResponse\"\x11\x8a\x92\x03\r\n\x0b/api/routes\x12_\n\nListTopics\x12\x16.google.protobuf.Empty\x1a&.yamcs.protobuf.web.ListTopicsResponse\"\x11\x8a\x92\x03\r\n\x0b/api/topics\x12r\n\x0bListThreads\x12&.yamcs.protobuf.web.ListThreadsRequest\x1a\'.yamcs.protobuf.web.ListThreadsResponse\"\x12\x8a\x92\x03\x0e\n\x0c/api/threads\x12j\n\tGetThread\x12$.yamcs.protobuf.web.GetThreadRequest\x1a\x1e.yamcs.protobuf.web.ThreadInfo\"\x17\x8a\x92\x03\x13\n\x11/api/threads/{id}\x12S\n\x0b\x44umpThreads\x12\x16.google.protobuf.Empty\x1a\x13.yamcs.api.HttpBody\"\x17\x8a\x92\x03\x13\n\x11/api/threads:dump\x12\x62\n\x0eGetHttpTraffic\x12\x16.google.protobuf.Empty\x1a\x1f.yamcs.protobuf.web.HttpTraffic\"\x17\x8a\x92\x03\x13\n\x11/api/http-trafficB*\n\x12org.yamcs.protobufB\x12ServerServiceProtoP\x01')
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_api_dot_httpbody__pb2.DESCRIPTOR,])




_GETTHREADREQUEST = _descriptor.Descriptor(
  name='GetThreadRequest',
  full_name='yamcs.protobuf.web.GetThreadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.web.GetThreadRequest.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=147,
  serialized_end=177,
)


_LISTTHREADSRESPONSE = _descriptor.Descriptor(
  name='ListThreadsResponse',
  full_name='yamcs.protobuf.web.ListThreadsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='threads', full_name='yamcs.protobuf.web.ListThreadsResponse.threads', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=179,
  serialized_end=249,
)


_LISTROUTESRESPONSE = _descriptor.Descriptor(
  name='ListRoutesResponse',
  full_name='yamcs.protobuf.web.ListRoutesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='routes', full_name='yamcs.protobuf.web.ListRoutesResponse.routes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=251,
  serialized_end=318,
)


_LISTTOPICSRESPONSE = _descriptor.Descriptor(
  name='ListTopicsResponse',
  full_name='yamcs.protobuf.web.ListTopicsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topics', full_name='yamcs.protobuf.web.ListTopicsResponse.topics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=320,
  serialized_end=387,
)


_HTTPTRAFFIC = _descriptor.Descriptor(
  name='HttpTraffic',
  full_name='yamcs.protobuf.web.HttpTraffic',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='readBytes', full_name='yamcs.protobuf.web.HttpTraffic.readBytes', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writtenBytes', full_name='yamcs.protobuf.web.HttpTraffic.writtenBytes', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readThroughput', full_name='yamcs.protobuf.web.HttpTraffic.readThroughput', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writeThroughput', full_name='yamcs.protobuf.web.HttpTraffic.writeThroughput', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='connections', full_name='yamcs.protobuf.web.HttpTraffic.connections', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=390,
  serialized_end=556,
)


_ROUTEINFO = _descriptor.Descriptor(
  name='RouteInfo',
  full_name='yamcs.protobuf.web.RouteInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='service', full_name='yamcs.protobuf.web.RouteInfo.service', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='yamcs.protobuf.web.RouteInfo.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.web.RouteInfo.description', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='httpMethod', full_name='yamcs.protobuf.web.RouteInfo.httpMethod', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url', full_name='yamcs.protobuf.web.RouteInfo.url', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputType', full_name='yamcs.protobuf.web.RouteInfo.inputType', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputType', full_name='yamcs.protobuf.web.RouteInfo.outputType', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='yamcs.protobuf.web.RouteInfo.deprecated', index=7,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='requestCount', full_name='yamcs.protobuf.web.RouteInfo.requestCount', index=8,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorCount', full_name='yamcs.protobuf.web.RouteInfo.errorCount', index=9,
      number=10, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='logFormat', full_name='yamcs.protobuf.web.RouteInfo.logFormat', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=559,
  serialized_end=777,
)


_TOPICINFO = _descriptor.Descriptor(
  name='TopicInfo',
  full_name='yamcs.protobuf.web.TopicInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='yamcs.protobuf.web.TopicInfo.topic', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='service', full_name='yamcs.protobuf.web.TopicInfo.service', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='yamcs.protobuf.web.TopicInfo.method', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.web.TopicInfo.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='inputType', full_name='yamcs.protobuf.web.TopicInfo.inputType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='outputType', full_name='yamcs.protobuf.web.TopicInfo.outputType', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='deprecated', full_name='yamcs.protobuf.web.TopicInfo.deprecated', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=780,
  serialized_end=919,
)


_TRACEELEMENTINFO = _descriptor.Descriptor(
  name='TraceElementInfo',
  full_name='yamcs.protobuf.web.TraceElementInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='className', full_name='yamcs.protobuf.web.TraceElementInfo.className', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='fileName', full_name='yamcs.protobuf.web.TraceElementInfo.fileName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='methodName', full_name='yamcs.protobuf.web.TraceElementInfo.methodName', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='lineNumber', full_name='yamcs.protobuf.web.TraceElementInfo.lineNumber', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=921,
  serialized_end=1016,
)


_LISTTHREADSREQUEST = _descriptor.Descriptor(
  name='ListThreadsRequest',
  full_name='yamcs.protobuf.web.ListThreadsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='depth', full_name='yamcs.protobuf.web.ListThreadsRequest.depth', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1018,
  serialized_end=1053,
)


_THREADGROUPINFO = _descriptor.Descriptor(
  name='ThreadGroupInfo',
  full_name='yamcs.protobuf.web.ThreadGroupInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.web.ThreadGroupInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='daemon', full_name='yamcs.protobuf.web.ThreadGroupInfo.daemon', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parent', full_name='yamcs.protobuf.web.ThreadGroupInfo.parent', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1055,
  serialized_end=1155,
)


_THREADINFO = _descriptor.Descriptor(
  name='ThreadInfo',
  full_name='yamcs.protobuf.web.ThreadInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.web.ThreadInfo.id', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.web.ThreadInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.web.ThreadInfo.state', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='native', full_name='yamcs.protobuf.web.ThreadInfo.native', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='suspended', full_name='yamcs.protobuf.web.ThreadInfo.suspended', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='group', full_name='yamcs.protobuf.web.ThreadInfo.group', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='trace', full_name='yamcs.protobuf.web.ThreadInfo.trace', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1158,
  serialized_end=1351,
)


_GETSERVERINFORESPONSE_PLUGININFO = _descriptor.Descriptor(
  name='PluginInfo',
  full_name='yamcs.protobuf.web.GetServerInfoResponse.PluginInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.web.GetServerInfoResponse.PluginInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='yamcs.protobuf.web.GetServerInfoResponse.PluginInfo.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='version', full_name='yamcs.protobuf.web.GetServerInfoResponse.PluginInfo.version', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='vendor', full_name='yamcs.protobuf.web.GetServerInfoResponse.PluginInfo.vendor', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1623,
  serialized_end=1703,
)

_GETSERVERINFORESPONSE_COMMANDOPTIONINFO = _descriptor.Descriptor(
  name='CommandOptionInfo',
  full_name='yamcs.protobuf.web.GetServerInfoResponse.CommandOptionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.web.GetServerInfoResponse.CommandOptionInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='verboseName', full_name='yamcs.protobuf.web.GetServerInfoResponse.CommandOptionInfo.verboseName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.web.GetServerInfoResponse.CommandOptionInfo.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='help', full_name='yamcs.protobuf.web.GetServerInfoResponse.CommandOptionInfo.help', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1705,
  serialized_end=1785,
)

_GETSERVERINFORESPONSE = _descriptor.Descriptor(
  name='GetServerInfoResponse',
  full_name='yamcs.protobuf.web.GetServerInfoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='yamcsVersion', full_name='yamcs.protobuf.web.GetServerInfoResponse.yamcsVersion', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='revision', full_name='yamcs.protobuf.web.GetServerInfoResponse.revision', index=1,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serverId', full_name='yamcs.protobuf.web.GetServerInfoResponse.serverId', index=2,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='defaultYamcsInstance', full_name='yamcs.protobuf.web.GetServerInfoResponse.defaultYamcsInstance', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='plugins', full_name='yamcs.protobuf.web.GetServerInfoResponse.plugins', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandOptions', full_name='yamcs.protobuf.web.GetServerInfoResponse.commandOptions', index=5,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_GETSERVERINFORESPONSE_PLUGININFO, _GETSERVERINFORESPONSE_COMMANDOPTIONINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1354,
  serialized_end=1785,
)


_CLIENTCONNECTIONINFO_HTTPREQUESTINFO = _descriptor.Descriptor(
  name='HttpRequestInfo',
  full_name='yamcs.protobuf.web.ClientConnectionInfo.HttpRequestInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='protocol', full_name='yamcs.protobuf.web.ClientConnectionInfo.HttpRequestInfo.protocol', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='method', full_name='yamcs.protobuf.web.ClientConnectionInfo.HttpRequestInfo.method', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uri', full_name='yamcs.protobuf.web.ClientConnectionInfo.HttpRequestInfo.uri', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keepAlive', full_name='yamcs.protobuf.web.ClientConnectionInfo.HttpRequestInfo.keepAlive', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='userAgent', full_name='yamcs.protobuf.web.ClientConnectionInfo.HttpRequestInfo.userAgent', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2082,
  serialized_end=2184,
)

_CLIENTCONNECTIONINFO = _descriptor.Descriptor(
  name='ClientConnectionInfo',
  full_name='yamcs.protobuf.web.ClientConnectionInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.web.ClientConnectionInfo.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='open', full_name='yamcs.protobuf.web.ClientConnectionInfo.open', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='active', full_name='yamcs.protobuf.web.ClientConnectionInfo.active', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writable', full_name='yamcs.protobuf.web.ClientConnectionInfo.writable', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remoteAddress', full_name='yamcs.protobuf.web.ClientConnectionInfo.remoteAddress', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readBytes', full_name='yamcs.protobuf.web.ClientConnectionInfo.readBytes', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writtenBytes', full_name='yamcs.protobuf.web.ClientConnectionInfo.writtenBytes', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='readThroughput', full_name='yamcs.protobuf.web.ClientConnectionInfo.readThroughput', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='writeThroughput', full_name='yamcs.protobuf.web.ClientConnectionInfo.writeThroughput', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='httpRequest', full_name='yamcs.protobuf.web.ClientConnectionInfo.httpRequest', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='username', full_name='yamcs.protobuf.web.ClientConnectionInfo.username', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CLIENTCONNECTIONINFO_HTTPREQUESTINFO, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1788,
  serialized_end=2184,
)

_LISTTHREADSRESPONSE.fields_by_name['threads'].message_type = _THREADINFO
_LISTROUTESRESPONSE.fields_by_name['routes'].message_type = _ROUTEINFO
_LISTTOPICSRESPONSE.fields_by_name['topics'].message_type = _TOPICINFO
_HTTPTRAFFIC.fields_by_name['connections'].message_type = _CLIENTCONNECTIONINFO
_THREADGROUPINFO.fields_by_name['parent'].message_type = _THREADGROUPINFO
_THREADINFO.fields_by_name['group'].message_type = _THREADGROUPINFO
_THREADINFO.fields_by_name['trace'].message_type = _TRACEELEMENTINFO
_GETSERVERINFORESPONSE_PLUGININFO.containing_type = _GETSERVERINFORESPONSE
_GETSERVERINFORESPONSE_COMMANDOPTIONINFO.containing_type = _GETSERVERINFORESPONSE
_GETSERVERINFORESPONSE.fields_by_name['plugins'].message_type = _GETSERVERINFORESPONSE_PLUGININFO
_GETSERVERINFORESPONSE.fields_by_name['commandOptions'].message_type = _GETSERVERINFORESPONSE_COMMANDOPTIONINFO
_CLIENTCONNECTIONINFO_HTTPREQUESTINFO.containing_type = _CLIENTCONNECTIONINFO
_CLIENTCONNECTIONINFO.fields_by_name['httpRequest'].message_type = _CLIENTCONNECTIONINFO_HTTPREQUESTINFO
DESCRIPTOR.message_types_by_name['GetThreadRequest'] = _GETTHREADREQUEST
DESCRIPTOR.message_types_by_name['ListThreadsResponse'] = _LISTTHREADSRESPONSE
DESCRIPTOR.message_types_by_name['ListRoutesResponse'] = _LISTROUTESRESPONSE
DESCRIPTOR.message_types_by_name['ListTopicsResponse'] = _LISTTOPICSRESPONSE
DESCRIPTOR.message_types_by_name['HttpTraffic'] = _HTTPTRAFFIC
DESCRIPTOR.message_types_by_name['RouteInfo'] = _ROUTEINFO
DESCRIPTOR.message_types_by_name['TopicInfo'] = _TOPICINFO
DESCRIPTOR.message_types_by_name['TraceElementInfo'] = _TRACEELEMENTINFO
DESCRIPTOR.message_types_by_name['ListThreadsRequest'] = _LISTTHREADSREQUEST
DESCRIPTOR.message_types_by_name['ThreadGroupInfo'] = _THREADGROUPINFO
DESCRIPTOR.message_types_by_name['ThreadInfo'] = _THREADINFO
DESCRIPTOR.message_types_by_name['GetServerInfoResponse'] = _GETSERVERINFORESPONSE
DESCRIPTOR.message_types_by_name['ClientConnectionInfo'] = _CLIENTCONNECTIONINFO
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetThreadRequest = _reflection.GeneratedProtocolMessageType('GetThreadRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTHREADREQUEST,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.GetThreadRequest)
  ))
_sym_db.RegisterMessage(GetThreadRequest)

ListThreadsResponse = _reflection.GeneratedProtocolMessageType('ListThreadsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTTHREADSRESPONSE,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListThreadsResponse)
  ))
_sym_db.RegisterMessage(ListThreadsResponse)

ListRoutesResponse = _reflection.GeneratedProtocolMessageType('ListRoutesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTROUTESRESPONSE,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListRoutesResponse)
  ))
_sym_db.RegisterMessage(ListRoutesResponse)

ListTopicsResponse = _reflection.GeneratedProtocolMessageType('ListTopicsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTTOPICSRESPONSE,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListTopicsResponse)
  ))
_sym_db.RegisterMessage(ListTopicsResponse)

HttpTraffic = _reflection.GeneratedProtocolMessageType('HttpTraffic', (_message.Message,), dict(
  DESCRIPTOR = _HTTPTRAFFIC,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.HttpTraffic)
  ))
_sym_db.RegisterMessage(HttpTraffic)

RouteInfo = _reflection.GeneratedProtocolMessageType('RouteInfo', (_message.Message,), dict(
  DESCRIPTOR = _ROUTEINFO,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.RouteInfo)
  ))
_sym_db.RegisterMessage(RouteInfo)

TopicInfo = _reflection.GeneratedProtocolMessageType('TopicInfo', (_message.Message,), dict(
  DESCRIPTOR = _TOPICINFO,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.TopicInfo)
  ))
_sym_db.RegisterMessage(TopicInfo)

TraceElementInfo = _reflection.GeneratedProtocolMessageType('TraceElementInfo', (_message.Message,), dict(
  DESCRIPTOR = _TRACEELEMENTINFO,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.TraceElementInfo)
  ))
_sym_db.RegisterMessage(TraceElementInfo)

ListThreadsRequest = _reflection.GeneratedProtocolMessageType('ListThreadsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTTHREADSREQUEST,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ListThreadsRequest)
  ))
_sym_db.RegisterMessage(ListThreadsRequest)

ThreadGroupInfo = _reflection.GeneratedProtocolMessageType('ThreadGroupInfo', (_message.Message,), dict(
  DESCRIPTOR = _THREADGROUPINFO,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ThreadGroupInfo)
  ))
_sym_db.RegisterMessage(ThreadGroupInfo)

ThreadInfo = _reflection.GeneratedProtocolMessageType('ThreadInfo', (_message.Message,), dict(
  DESCRIPTOR = _THREADINFO,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ThreadInfo)
  ))
_sym_db.RegisterMessage(ThreadInfo)

GetServerInfoResponse = _reflection.GeneratedProtocolMessageType('GetServerInfoResponse', (_message.Message,), dict(

  PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), dict(
    DESCRIPTOR = _GETSERVERINFORESPONSE_PLUGININFO,
    __module__ = 'yamcs.protobuf.web.server_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.GetServerInfoResponse.PluginInfo)
    ))
  ,

  CommandOptionInfo = _reflection.GeneratedProtocolMessageType('CommandOptionInfo', (_message.Message,), dict(
    DESCRIPTOR = _GETSERVERINFORESPONSE_COMMANDOPTIONINFO,
    __module__ = 'yamcs.protobuf.web.server_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.GetServerInfoResponse.CommandOptionInfo)
    ))
  ,
  DESCRIPTOR = _GETSERVERINFORESPONSE,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.GetServerInfoResponse)
  ))
_sym_db.RegisterMessage(GetServerInfoResponse)
_sym_db.RegisterMessage(GetServerInfoResponse.PluginInfo)
_sym_db.RegisterMessage(GetServerInfoResponse.CommandOptionInfo)

ClientConnectionInfo = _reflection.GeneratedProtocolMessageType('ClientConnectionInfo', (_message.Message,), dict(

  HttpRequestInfo = _reflection.GeneratedProtocolMessageType('HttpRequestInfo', (_message.Message,), dict(
    DESCRIPTOR = _CLIENTCONNECTIONINFO_HTTPREQUESTINFO,
    __module__ = 'yamcs.protobuf.web.server_service_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ClientConnectionInfo.HttpRequestInfo)
    ))
  ,
  DESCRIPTOR = _CLIENTCONNECTIONINFO,
  __module__ = 'yamcs.protobuf.web.server_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.ClientConnectionInfo)
  ))
_sym_db.RegisterMessage(ClientConnectionInfo)
_sym_db.RegisterMessage(ClientConnectionInfo.HttpRequestInfo)


DESCRIPTOR._options = None

_SERVERAPI = _descriptor.ServiceDescriptor(
  name='ServerApi',
  full_name='yamcs.protobuf.web.ServerApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2187,
  serialized_end=2897,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetServerInfo',
    full_name='yamcs.protobuf.web.ServerApi.GetServerInfo',
    index=0,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_GETSERVERINFORESPONSE,
    serialized_options=_b('\212\222\003\006\n\004/api'),
  ),
  _descriptor.MethodDescriptor(
    name='ListRoutes',
    full_name='yamcs.protobuf.web.ServerApi.ListRoutes',
    index=1,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTROUTESRESPONSE,
    serialized_options=_b('\212\222\003\r\n\013/api/routes'),
  ),
  _descriptor.MethodDescriptor(
    name='ListTopics',
    full_name='yamcs.protobuf.web.ServerApi.ListTopics',
    index=2,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_LISTTOPICSRESPONSE,
    serialized_options=_b('\212\222\003\r\n\013/api/topics'),
  ),
  _descriptor.MethodDescriptor(
    name='ListThreads',
    full_name='yamcs.protobuf.web.ServerApi.ListThreads',
    index=3,
    containing_service=None,
    input_type=_LISTTHREADSREQUEST,
    output_type=_LISTTHREADSRESPONSE,
    serialized_options=_b('\212\222\003\016\n\014/api/threads'),
  ),
  _descriptor.MethodDescriptor(
    name='GetThread',
    full_name='yamcs.protobuf.web.ServerApi.GetThread',
    index=4,
    containing_service=None,
    input_type=_GETTHREADREQUEST,
    output_type=_THREADINFO,
    serialized_options=_b('\212\222\003\023\n\021/api/threads/{id}'),
  ),
  _descriptor.MethodDescriptor(
    name='DumpThreads',
    full_name='yamcs.protobuf.web.ServerApi.DumpThreads',
    index=5,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=yamcs_dot_api_dot_httpbody__pb2._HTTPBODY,
    serialized_options=_b('\212\222\003\023\n\021/api/threads:dump'),
  ),
  _descriptor.MethodDescriptor(
    name='GetHttpTraffic',
    full_name='yamcs.protobuf.web.ServerApi.GetHttpTraffic',
    index=6,
    containing_service=None,
    input_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    output_type=_HTTPTRAFFIC,
    serialized_options=_b('\212\222\003\023\n\021/api/http-traffic'),
  ),
])
_sym_db.RegisterServiceDescriptor(_SERVERAPI)

DESCRIPTOR.services_by_name['ServerApi'] = _SERVERAPI

# @@protoc_insertion_point(module_scope)
