# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/web/auth.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.protobuf.iam import iam_pb2 as yamcs_dot_protobuf_dot_iam_dot_iam__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/web/auth.proto',
  package='yamcs.protobuf.web',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\tAuthProtoP\001'),
  serialized_pb=_b('\n\x1dyamcs/protobuf/web/auth.proto\x12\x12yamcs.protobuf.web\x1a\x1cyamcs/protobuf/iam/iam.proto\"p\n\x08\x41uthInfo\x12\x1d\n\x15requireAuthentication\x18\x01 \x01(\x08\x12\x0e\n\x06spnego\x18\x02 \x01(\x08\x12\x35\n\x06openid\x18\x03 \x01(\x0b\x32%.yamcs.protobuf.web.OpenIDConnectInfo\"S\n\x11OpenIDConnectInfo\x12\x10\n\x08\x63lientId\x18\x01 \x01(\t\x12\x1d\n\x15\x61uthorizationEndpoint\x18\x02 \x01(\t\x12\r\n\x05scope\x18\x03 \x01(\t\"\x90\x01\n\rTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x12\n\ntoken_type\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\x05\x12\x15\n\rrefresh_token\x18\x04 \x01(\t\x12*\n\x04user\x18\x05 \x01(\x0b\x32\x1c.yamcs.protobuf.iam.UserInfoB!\n\x12org.yamcs.protobufB\tAuthProtoP\x01')
  ,
  dependencies=[yamcs_dot_protobuf_dot_iam_dot_iam__pb2.DESCRIPTOR,])




_AUTHINFO = _descriptor.Descriptor(
  name='AuthInfo',
  full_name='yamcs.protobuf.web.AuthInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='requireAuthentication', full_name='yamcs.protobuf.web.AuthInfo.requireAuthentication', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='spnego', full_name='yamcs.protobuf.web.AuthInfo.spnego', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='openid', full_name='yamcs.protobuf.web.AuthInfo.openid', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=83,
  serialized_end=195,
)


_OPENIDCONNECTINFO = _descriptor.Descriptor(
  name='OpenIDConnectInfo',
  full_name='yamcs.protobuf.web.OpenIDConnectInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='clientId', full_name='yamcs.protobuf.web.OpenIDConnectInfo.clientId', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='authorizationEndpoint', full_name='yamcs.protobuf.web.OpenIDConnectInfo.authorizationEndpoint', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='scope', full_name='yamcs.protobuf.web.OpenIDConnectInfo.scope', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=197,
  serialized_end=280,
)


_TOKENRESPONSE = _descriptor.Descriptor(
  name='TokenResponse',
  full_name='yamcs.protobuf.web.TokenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='access_token', full_name='yamcs.protobuf.web.TokenResponse.access_token', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='token_type', full_name='yamcs.protobuf.web.TokenResponse.token_type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='expires_in', full_name='yamcs.protobuf.web.TokenResponse.expires_in', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='refresh_token', full_name='yamcs.protobuf.web.TokenResponse.refresh_token', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='user', full_name='yamcs.protobuf.web.TokenResponse.user', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=283,
  serialized_end=427,
)

_AUTHINFO.fields_by_name['openid'].message_type = _OPENIDCONNECTINFO
_TOKENRESPONSE.fields_by_name['user'].message_type = yamcs_dot_protobuf_dot_iam_dot_iam__pb2._USERINFO
DESCRIPTOR.message_types_by_name['AuthInfo'] = _AUTHINFO
DESCRIPTOR.message_types_by_name['OpenIDConnectInfo'] = _OPENIDCONNECTINFO
DESCRIPTOR.message_types_by_name['TokenResponse'] = _TOKENRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

AuthInfo = _reflection.GeneratedProtocolMessageType('AuthInfo', (_message.Message,), dict(
  DESCRIPTOR = _AUTHINFO,
  __module__ = 'yamcs.protobuf.web.auth_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.AuthInfo)
  ))
_sym_db.RegisterMessage(AuthInfo)

OpenIDConnectInfo = _reflection.GeneratedProtocolMessageType('OpenIDConnectInfo', (_message.Message,), dict(
  DESCRIPTOR = _OPENIDCONNECTINFO,
  __module__ = 'yamcs.protobuf.web.auth_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.OpenIDConnectInfo)
  ))
_sym_db.RegisterMessage(OpenIDConnectInfo)

TokenResponse = _reflection.GeneratedProtocolMessageType('TokenResponse', (_message.Message,), dict(
  DESCRIPTOR = _TOKENRESPONSE,
  __module__ = 'yamcs.protobuf.web.auth_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.web.TokenResponse)
  ))
_sym_db.RegisterMessage(TokenResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
