# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/yamcs.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/yamcs.proto',
  package='yamcs.protobuf',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobuf'),
  serialized_pb=_b('\n\x1ayamcs/protobuf/yamcs.proto\x12\x0eyamcs.protobuf\x1a\x1fgoogle/protobuf/timestamp.proto\"\xa1\x04\n\x05Value\x12(\n\x04type\x18\x01 \x02(\x0e\x32\x1a.yamcs.protobuf.Value.Type\x12\x12\n\nfloatValue\x18\x02 \x01(\x02\x12\x13\n\x0b\x64oubleValue\x18\x03 \x01(\x01\x12\x13\n\x0bsint32Value\x18\x04 \x01(\x11\x12\x13\n\x0buint32Value\x18\x05 \x01(\r\x12\x13\n\x0b\x62inaryValue\x18\x06 \x01(\x0c\x12\x13\n\x0bstringValue\x18\x07 \x01(\t\x12\x16\n\x0etimestampValue\x18\x08 \x01(\x03\x12\x13\n\x0buint64Value\x18\t \x01(\x04\x12\x13\n\x0bsint64Value\x18\n \x01(\x12\x12\x14\n\x0c\x62ooleanValue\x18\x0b \x01(\x08\x12\x36\n\x0e\x61ggregateValue\x18\x0c \x01(\x0b\x32\x1e.yamcs.protobuf.AggregateValue\x12)\n\narrayValue\x18\r \x03(\x0b\x32\x15.yamcs.protobuf.Value\"\xb5\x01\n\x04Type\x12\t\n\x05\x46LOAT\x10\x00\x12\n\n\x06\x44OUBLE\x10\x01\x12\n\n\x06UINT32\x10\x02\x12\n\n\x06SINT32\x10\x03\x12\n\n\x06\x42INARY\x10\x04\x12\n\n\x06STRING\x10\x05\x12\r\n\tTIMESTAMP\x10\x06\x12\n\n\x06UINT64\x10\x07\x12\n\n\x06SINT64\x10\x08\x12\x0b\n\x07\x42OOLEAN\x10\t\x12\r\n\tAGGREGATE\x10\n\x12\t\n\x05\x41RRAY\x10\x0b\x12\x0e\n\nENUMERATED\x10\x0c\x12\x08\n\x04NONE\x10\r\"D\n\x0e\x41ggregateValue\x12\x0c\n\x04name\x18\x01 \x03(\t\x12$\n\x05value\x18\x02 \x03(\x0b\x32\x15.yamcs.protobuf.Value\"0\n\rNamedObjectId\x12\x0c\n\x04name\x18\x01 \x02(\t\x12\x11\n\tnamespace\x18\x02 \x01(\t\">\n\x0fNamedObjectList\x12+\n\x04list\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\"\xa6\x02\n\rArchiveRecord\x12)\n\x02id\x18\x01 \x01(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x0b\n\x03num\x18\x04 \x01(\x05\x12\x10\n\x08seqFirst\x18\x06 \x01(\x03\x12\x0f\n\x07seqLast\x18\x07 \x01(\x03\x12)\n\x05\x66irst\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04last\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x05\x65xtra\x18\n \x03(\x0b\x32(.yamcs.protobuf.ArchiveRecord.ExtraEntry\x1a,\n\nExtraEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa5\x01\n\x0bReplaySpeed\x12\x39\n\x04type\x18\x01 \x02(\x0e\x32+.yamcs.protobuf.ReplaySpeed.ReplaySpeedType\x12\r\n\x05param\x18\x02 \x01(\x02\"L\n\x0fReplaySpeedType\x12\x08\n\x04\x41\x46\x41P\x10\x01\x12\x0f\n\x0b\x46IXED_DELAY\x10\x02\x12\x0c\n\x08REALTIME\x10\x03\x12\x10\n\x0cSTEP_BY_STEP\x10\x04\"\x8d\x04\n\rReplayRequest\x12)\n\x05start\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\tendAction\x18\x03 \x01(\x0e\x32\x19.yamcs.protobuf.EndAction:\x04QUIT\x12*\n\x05speed\x18\x04 \x01(\x0b\x32\x1b.yamcs.protobuf.ReplaySpeed\x12\x0f\n\x07reverse\x18\x0f \x01(\x08\x12@\n\x10parameterRequest\x18\x08 \x01(\x0b\x32&.yamcs.protobuf.ParameterReplayRequest\x12:\n\rpacketRequest\x18\t \x01(\x0b\x32#.yamcs.protobuf.PacketReplayRequest\x12\x38\n\x0c\x65ventRequest\x18\n \x01(\x0b\x32\".yamcs.protobuf.EventReplayRequest\x12J\n\x15\x63ommandHistoryRequest\x18\x0b \x01(\x0b\x32+.yamcs.protobuf.CommandHistoryReplayRequest\x12\x32\n\tppRequest\x18\x0c \x01(\x0b\x32\x1f.yamcs.protobuf.PpReplayRequest\"\x85\x01\n\x16ParameterReplayRequest\x12\x31\n\nnameFilter\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\x12\x16\n\x07sendRaw\x18\x02 \x01(\x08:\x05\x66\x61lse\x12 \n\x11performMonitoring\x18\x03 \x01(\x08:\x05\x66\x61lse\"H\n\x13PacketReplayRequest\x12\x31\n\nnameFilter\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\"\x14\n\x12\x45ventReplayRequest\"P\n\x1b\x43ommandHistoryReplayRequest\x12\x31\n\nnameFilter\x18\x01 \x03(\x0b\x32\x1d.yamcs.protobuf.NamedObjectId\"D\n\x0fPpReplayRequest\x12\x17\n\x0fgroupNameFilter\x18\x01 \x03(\t\x12\x18\n\x10groupNameExclude\x18\x02 \x03(\t\"\xed\x01\n\x0cReplayStatus\x12\x37\n\x05state\x18\x01 \x02(\x0e\x32(.yamcs.protobuf.ReplayStatus.ReplayState\x12.\n\x07request\x18\x02 \x01(\x0b\x32\x1d.yamcs.protobuf.ReplayRequest\x12\x14\n\x0c\x65rrorMessage\x18\x03 \x01(\t\"^\n\x0bReplayState\x12\x12\n\x0eINITIALIZATION\x10\x00\x12\x0b\n\x07RUNNING\x10\x01\x12\x0b\n\x07STOPPED\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\n\n\x06PAUSED\x10\x04\x12\n\n\x06\x43LOSED\x10\x05*)\n\tEndAction\x12\x08\n\x04LOOP\x10\x01\x12\x08\n\x04QUIT\x10\x02\x12\x08\n\x04STOP\x10\x03\x42\x14\n\x12org.yamcs.protobuf')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])

_ENDACTION = _descriptor.EnumDescriptor(
  name='EndAction',
  full_name='yamcs.protobuf.EndAction',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='LOOP', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUIT', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOP', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2428,
  serialized_end=2469,
)
_sym_db.RegisterEnumDescriptor(_ENDACTION)

EndAction = enum_type_wrapper.EnumTypeWrapper(_ENDACTION)
LOOP = 1
QUIT = 2
STOP = 3


_VALUE_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='yamcs.protobuf.Value.Type',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='FLOAT', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOUBLE', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UINT32', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SINT32', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BINARY', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STRING', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIMESTAMP', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UINT64', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SINT64', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BOOLEAN', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AGGREGATE', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ARRAY', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ENUMERATED', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NONE', index=13, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=444,
  serialized_end=625,
)
_sym_db.RegisterEnumDescriptor(_VALUE_TYPE)

_REPLAYSPEED_REPLAYSPEEDTYPE = _descriptor.EnumDescriptor(
  name='ReplaySpeedType',
  full_name='yamcs.protobuf.ReplaySpeed.ReplaySpeedType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='AFAP', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FIXED_DELAY', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='REALTIME', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STEP_BY_STEP', index=3, number=4,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1198,
  serialized_end=1274,
)
_sym_db.RegisterEnumDescriptor(_REPLAYSPEED_REPLAYSPEEDTYPE)

_REPLAYSTATUS_REPLAYSTATE = _descriptor.EnumDescriptor(
  name='ReplayState',
  full_name='yamcs.protobuf.ReplayStatus.ReplayState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='INITIALIZATION', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='STOPPED', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CLOSED', index=5, number=5,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2332,
  serialized_end=2426,
)
_sym_db.RegisterEnumDescriptor(_REPLAYSTATUS_REPLAYSTATE)


_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='yamcs.protobuf.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.Value.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='floatValue', full_name='yamcs.protobuf.Value.floatValue', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='doubleValue', full_name='yamcs.protobuf.Value.doubleValue', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sint32Value', full_name='yamcs.protobuf.Value.sint32Value', index=3,
      number=4, type=17, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint32Value', full_name='yamcs.protobuf.Value.uint32Value', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='binaryValue', full_name='yamcs.protobuf.Value.binaryValue', index=5,
      number=6, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stringValue', full_name='yamcs.protobuf.Value.stringValue', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timestampValue', full_name='yamcs.protobuf.Value.timestampValue', index=7,
      number=8, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uint64Value', full_name='yamcs.protobuf.Value.uint64Value', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sint64Value', full_name='yamcs.protobuf.Value.sint64Value', index=9,
      number=10, type=18, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='booleanValue', full_name='yamcs.protobuf.Value.booleanValue', index=10,
      number=11, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='aggregateValue', full_name='yamcs.protobuf.Value.aggregateValue', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='arrayValue', full_name='yamcs.protobuf.Value.arrayValue', index=12,
      number=13, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _VALUE_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=80,
  serialized_end=625,
)


_AGGREGATEVALUE = _descriptor.Descriptor(
  name='AggregateValue',
  full_name='yamcs.protobuf.AggregateValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.AggregateValue.name', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.AggregateValue.value', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=627,
  serialized_end=695,
)


_NAMEDOBJECTID = _descriptor.Descriptor(
  name='NamedObjectId',
  full_name='yamcs.protobuf.NamedObjectId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.NamedObjectId.name', index=0,
      number=1, type=9, cpp_type=9, label=2,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='namespace', full_name='yamcs.protobuf.NamedObjectId.namespace', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=697,
  serialized_end=745,
)


_NAMEDOBJECTLIST = _descriptor.Descriptor(
  name='NamedObjectList',
  full_name='yamcs.protobuf.NamedObjectList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='list', full_name='yamcs.protobuf.NamedObjectList.list', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=747,
  serialized_end=809,
)


_ARCHIVERECORD_EXTRAENTRY = _descriptor.Descriptor(
  name='ExtraEntry',
  full_name='yamcs.protobuf.ArchiveRecord.ExtraEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='yamcs.protobuf.ArchiveRecord.ExtraEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.ArchiveRecord.ExtraEntry.value', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=_b('8\001'),
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1062,
  serialized_end=1106,
)

_ARCHIVERECORD = _descriptor.Descriptor(
  name='ArchiveRecord',
  full_name='yamcs.protobuf.ArchiveRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.ArchiveRecord.id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='num', full_name='yamcs.protobuf.ArchiveRecord.num', index=1,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqFirst', full_name='yamcs.protobuf.ArchiveRecord.seqFirst', index=2,
      number=6, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='seqLast', full_name='yamcs.protobuf.ArchiveRecord.seqLast', index=3,
      number=7, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='first', full_name='yamcs.protobuf.ArchiveRecord.first', index=4,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last', full_name='yamcs.protobuf.ArchiveRecord.last', index=5,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra', full_name='yamcs.protobuf.ArchiveRecord.extra', index=6,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ARCHIVERECORD_EXTRAENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=812,
  serialized_end=1106,
)


_REPLAYSPEED = _descriptor.Descriptor(
  name='ReplaySpeed',
  full_name='yamcs.protobuf.ReplaySpeed',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.ReplaySpeed.type', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='param', full_name='yamcs.protobuf.ReplaySpeed.param', index=1,
      number=2, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REPLAYSPEED_REPLAYSPEEDTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1109,
  serialized_end=1274,
)


_REPLAYREQUEST = _descriptor.Descriptor(
  name='ReplayRequest',
  full_name='yamcs.protobuf.ReplayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.ReplayRequest.start', index=0,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.ReplayRequest.stop', index=1,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='endAction', full_name='yamcs.protobuf.ReplayRequest.endAction', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=2,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='speed', full_name='yamcs.protobuf.ReplayRequest.speed', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reverse', full_name='yamcs.protobuf.ReplayRequest.reverse', index=4,
      number=15, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='parameterRequest', full_name='yamcs.protobuf.ReplayRequest.parameterRequest', index=5,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='packetRequest', full_name='yamcs.protobuf.ReplayRequest.packetRequest', index=6,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='eventRequest', full_name='yamcs.protobuf.ReplayRequest.eventRequest', index=7,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='commandHistoryRequest', full_name='yamcs.protobuf.ReplayRequest.commandHistoryRequest', index=8,
      number=11, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ppRequest', full_name='yamcs.protobuf.ReplayRequest.ppRequest', index=9,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1277,
  serialized_end=1802,
)


_PARAMETERREPLAYREQUEST = _descriptor.Descriptor(
  name='ParameterReplayRequest',
  full_name='yamcs.protobuf.ParameterReplayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nameFilter', full_name='yamcs.protobuf.ParameterReplayRequest.nameFilter', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sendRaw', full_name='yamcs.protobuf.ParameterReplayRequest.sendRaw', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='performMonitoring', full_name='yamcs.protobuf.ParameterReplayRequest.performMonitoring', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=True, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1805,
  serialized_end=1938,
)


_PACKETREPLAYREQUEST = _descriptor.Descriptor(
  name='PacketReplayRequest',
  full_name='yamcs.protobuf.PacketReplayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nameFilter', full_name='yamcs.protobuf.PacketReplayRequest.nameFilter', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1940,
  serialized_end=2012,
)


_EVENTREPLAYREQUEST = _descriptor.Descriptor(
  name='EventReplayRequest',
  full_name='yamcs.protobuf.EventReplayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2014,
  serialized_end=2034,
)


_COMMANDHISTORYREPLAYREQUEST = _descriptor.Descriptor(
  name='CommandHistoryReplayRequest',
  full_name='yamcs.protobuf.CommandHistoryReplayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='nameFilter', full_name='yamcs.protobuf.CommandHistoryReplayRequest.nameFilter', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2036,
  serialized_end=2116,
)


_PPREPLAYREQUEST = _descriptor.Descriptor(
  name='PpReplayRequest',
  full_name='yamcs.protobuf.PpReplayRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='groupNameFilter', full_name='yamcs.protobuf.PpReplayRequest.groupNameFilter', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='groupNameExclude', full_name='yamcs.protobuf.PpReplayRequest.groupNameExclude', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2118,
  serialized_end=2186,
)


_REPLAYSTATUS = _descriptor.Descriptor(
  name='ReplayStatus',
  full_name='yamcs.protobuf.ReplayStatus',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.ReplayStatus.state', index=0,
      number=1, type=14, cpp_type=8, label=2,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='request', full_name='yamcs.protobuf.ReplayStatus.request', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='errorMessage', full_name='yamcs.protobuf.ReplayStatus.errorMessage', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _REPLAYSTATUS_REPLAYSTATE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2189,
  serialized_end=2426,
)

_VALUE.fields_by_name['type'].enum_type = _VALUE_TYPE
_VALUE.fields_by_name['aggregateValue'].message_type = _AGGREGATEVALUE
_VALUE.fields_by_name['arrayValue'].message_type = _VALUE
_VALUE_TYPE.containing_type = _VALUE
_AGGREGATEVALUE.fields_by_name['value'].message_type = _VALUE
_NAMEDOBJECTLIST.fields_by_name['list'].message_type = _NAMEDOBJECTID
_ARCHIVERECORD_EXTRAENTRY.containing_type = _ARCHIVERECORD
_ARCHIVERECORD.fields_by_name['id'].message_type = _NAMEDOBJECTID
_ARCHIVERECORD.fields_by_name['first'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ARCHIVERECORD.fields_by_name['last'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_ARCHIVERECORD.fields_by_name['extra'].message_type = _ARCHIVERECORD_EXTRAENTRY
_REPLAYSPEED.fields_by_name['type'].enum_type = _REPLAYSPEED_REPLAYSPEEDTYPE
_REPLAYSPEED_REPLAYSPEEDTYPE.containing_type = _REPLAYSPEED
_REPLAYREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REPLAYREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REPLAYREQUEST.fields_by_name['endAction'].enum_type = _ENDACTION
_REPLAYREQUEST.fields_by_name['speed'].message_type = _REPLAYSPEED
_REPLAYREQUEST.fields_by_name['parameterRequest'].message_type = _PARAMETERREPLAYREQUEST
_REPLAYREQUEST.fields_by_name['packetRequest'].message_type = _PACKETREPLAYREQUEST
_REPLAYREQUEST.fields_by_name['eventRequest'].message_type = _EVENTREPLAYREQUEST
_REPLAYREQUEST.fields_by_name['commandHistoryRequest'].message_type = _COMMANDHISTORYREPLAYREQUEST
_REPLAYREQUEST.fields_by_name['ppRequest'].message_type = _PPREPLAYREQUEST
_PARAMETERREPLAYREQUEST.fields_by_name['nameFilter'].message_type = _NAMEDOBJECTID
_PACKETREPLAYREQUEST.fields_by_name['nameFilter'].message_type = _NAMEDOBJECTID
_COMMANDHISTORYREPLAYREQUEST.fields_by_name['nameFilter'].message_type = _NAMEDOBJECTID
_REPLAYSTATUS.fields_by_name['state'].enum_type = _REPLAYSTATUS_REPLAYSTATE
_REPLAYSTATUS.fields_by_name['request'].message_type = _REPLAYREQUEST
_REPLAYSTATUS_REPLAYSTATE.containing_type = _REPLAYSTATUS
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
DESCRIPTOR.message_types_by_name['AggregateValue'] = _AGGREGATEVALUE
DESCRIPTOR.message_types_by_name['NamedObjectId'] = _NAMEDOBJECTID
DESCRIPTOR.message_types_by_name['NamedObjectList'] = _NAMEDOBJECTLIST
DESCRIPTOR.message_types_by_name['ArchiveRecord'] = _ARCHIVERECORD
DESCRIPTOR.message_types_by_name['ReplaySpeed'] = _REPLAYSPEED
DESCRIPTOR.message_types_by_name['ReplayRequest'] = _REPLAYREQUEST
DESCRIPTOR.message_types_by_name['ParameterReplayRequest'] = _PARAMETERREPLAYREQUEST
DESCRIPTOR.message_types_by_name['PacketReplayRequest'] = _PACKETREPLAYREQUEST
DESCRIPTOR.message_types_by_name['EventReplayRequest'] = _EVENTREPLAYREQUEST
DESCRIPTOR.message_types_by_name['CommandHistoryReplayRequest'] = _COMMANDHISTORYREPLAYREQUEST
DESCRIPTOR.message_types_by_name['PpReplayRequest'] = _PPREPLAYREQUEST
DESCRIPTOR.message_types_by_name['ReplayStatus'] = _REPLAYSTATUS
DESCRIPTOR.enum_types_by_name['EndAction'] = _ENDACTION
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), dict(
  DESCRIPTOR = _VALUE,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.Value)
  ))
_sym_db.RegisterMessage(Value)

AggregateValue = _reflection.GeneratedProtocolMessageType('AggregateValue', (_message.Message,), dict(
  DESCRIPTOR = _AGGREGATEVALUE,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.AggregateValue)
  ))
_sym_db.RegisterMessage(AggregateValue)

NamedObjectId = _reflection.GeneratedProtocolMessageType('NamedObjectId', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDOBJECTID,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.NamedObjectId)
  ))
_sym_db.RegisterMessage(NamedObjectId)

NamedObjectList = _reflection.GeneratedProtocolMessageType('NamedObjectList', (_message.Message,), dict(
  DESCRIPTOR = _NAMEDOBJECTLIST,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.NamedObjectList)
  ))
_sym_db.RegisterMessage(NamedObjectList)

ArchiveRecord = _reflection.GeneratedProtocolMessageType('ArchiveRecord', (_message.Message,), dict(

  ExtraEntry = _reflection.GeneratedProtocolMessageType('ExtraEntry', (_message.Message,), dict(
    DESCRIPTOR = _ARCHIVERECORD_EXTRAENTRY,
    __module__ = 'yamcs.protobuf.yamcs_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.ArchiveRecord.ExtraEntry)
    ))
  ,
  DESCRIPTOR = _ARCHIVERECORD,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.ArchiveRecord)
  ))
_sym_db.RegisterMessage(ArchiveRecord)
_sym_db.RegisterMessage(ArchiveRecord.ExtraEntry)

ReplaySpeed = _reflection.GeneratedProtocolMessageType('ReplaySpeed', (_message.Message,), dict(
  DESCRIPTOR = _REPLAYSPEED,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.ReplaySpeed)
  ))
_sym_db.RegisterMessage(ReplaySpeed)

ReplayRequest = _reflection.GeneratedProtocolMessageType('ReplayRequest', (_message.Message,), dict(
  DESCRIPTOR = _REPLAYREQUEST,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.ReplayRequest)
  ))
_sym_db.RegisterMessage(ReplayRequest)

ParameterReplayRequest = _reflection.GeneratedProtocolMessageType('ParameterReplayRequest', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETERREPLAYREQUEST,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.ParameterReplayRequest)
  ))
_sym_db.RegisterMessage(ParameterReplayRequest)

PacketReplayRequest = _reflection.GeneratedProtocolMessageType('PacketReplayRequest', (_message.Message,), dict(
  DESCRIPTOR = _PACKETREPLAYREQUEST,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.PacketReplayRequest)
  ))
_sym_db.RegisterMessage(PacketReplayRequest)

EventReplayRequest = _reflection.GeneratedProtocolMessageType('EventReplayRequest', (_message.Message,), dict(
  DESCRIPTOR = _EVENTREPLAYREQUEST,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.EventReplayRequest)
  ))
_sym_db.RegisterMessage(EventReplayRequest)

CommandHistoryReplayRequest = _reflection.GeneratedProtocolMessageType('CommandHistoryReplayRequest', (_message.Message,), dict(
  DESCRIPTOR = _COMMANDHISTORYREPLAYREQUEST,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.CommandHistoryReplayRequest)
  ))
_sym_db.RegisterMessage(CommandHistoryReplayRequest)

PpReplayRequest = _reflection.GeneratedProtocolMessageType('PpReplayRequest', (_message.Message,), dict(
  DESCRIPTOR = _PPREPLAYREQUEST,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.PpReplayRequest)
  ))
_sym_db.RegisterMessage(PpReplayRequest)

ReplayStatus = _reflection.GeneratedProtocolMessageType('ReplayStatus', (_message.Message,), dict(
  DESCRIPTOR = _REPLAYSTATUS,
  __module__ = 'yamcs.protobuf.yamcs_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.ReplayStatus)
  ))
_sym_db.RegisterMessage(ReplayStatus)


DESCRIPTOR._options = None
_ARCHIVERECORD_EXTRAENTRY._options = None
# @@protoc_insertion_point(module_scope)
