# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/table/table.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf import yamcs_pb2 as yamcs_dot_protobuf_dot_yamcs__pb2
from yamcs.protobuf.yamcsManagement import yamcsManagement_pb2 as yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/table/table.proto',
  package='yamcs.protobuf.table',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobuf'),
  serialized_pb=_b('\n yamcs/protobuf/table/table.proto\x12\x14yamcs.protobuf.table\x1a\x1byamcs/api/annotations.proto\x1a\x1ayamcs/protobuf/yamcs.proto\x1a\x34yamcs/protobuf/yamcsManagement/yamcsManagement.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"\xdd\x01\n\x03Row\x12\x35\n\x07\x63olumns\x18\x01 \x03(\x0b\x32$.yamcs.protobuf.table.Row.ColumnInfo\x12-\n\x05\x63\x65lls\x18\x02 \x03(\x0b\x32\x1e.yamcs.protobuf.table.Row.Cell\x1aH\n\nColumnInfo\x12\n\n\x02id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\t\x12\x12\n\nprotoClass\x18\x04 \x01(\t\x1a&\n\x04\x43\x65ll\x12\x10\n\x08\x63olumnId\x18\x01 \x01(\r\x12\x0c\n\x04\x64\x61ta\x18\x02 \x01(\x0c\"@\n\x0fReadRowsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\r\n\x05table\x18\x02 \x01(\t\x12\x0c\n\x04\x63ols\x18\x03 \x03(\t\"[\n\x10WriteRowsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\r\n\x05table\x18\x02 \x01(\t\x12&\n\x03row\x18\x03 \x01(\x0b\x32\x19.yamcs.protobuf.table.Row\"\"\n\x11WriteRowsResponse\x12\r\n\x05\x63ount\x18\x01 \x01(\r\")\n\x18WriteRowsExceptionDetail\x12\r\n\x05\x63ount\x18\x01 \x01(\r\"2\n\tListValue\x12%\n\x06values\x18\x01 \x03(\x0b\x32\x15.yamcs.protobuf.Value\"8\n\x11\x45xecuteSqlRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tstatement\x18\x02 \x01(\t\"m\n\tResultSet\x12\x31\n\x07\x63olumns\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.table.ColumnInfo\x12-\n\x04rows\x18\x02 \x03(\x0b\x32\x1f.yamcs.protobuf.table.ListValue\"%\n\x11ListTablesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"E\n\x12ListTablesResponse\x12/\n\x06tables\x18\x01 \x03(\x0b\x32\x1f.yamcs.protobuf.table.TableInfo\"1\n\x0fGetTableRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"n\n\x13GetTableDataRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0c\n\x04\x63ols\x18\x03 \x03(\t\x12\x0b\n\x03pos\x18\x04 \x01(\x03\x12\r\n\x05limit\x18\x05 \x01(\x05\x12\r\n\x05order\x18\x06 \x01(\t\"&\n\x12ListStreamsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"H\n\x13ListStreamsResponse\x12\x31\n\x07streams\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.table.StreamInfo\"2\n\x10GetStreamRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\":\n\x16SubscribeStreamRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0e\n\x06stream\x18\x02 \x01(\t\"@\n\nColumnData\x12\x0c\n\x04name\x18\x01 \x01(\t\x12$\n\x05value\x18\x02 \x01(\x0b\x32\x15.yamcs.protobuf.Value\"N\n\nStreamData\x12\x0e\n\x06stream\x18\x01 \x01(\t\x12\x30\n\x06\x63olumn\x18\x02 \x03(\x0b\x32 .yamcs.protobuf.table.ColumnData\"4\n SubscribeStreamStatisticsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"\x89\x01\n\tTableData\x12;\n\x06record\x18\x01 \x03(\x0b\x32+.yamcs.protobuf.table.TableData.TableRecord\x1a?\n\x0bTableRecord\x12\x30\n\x06\x63olumn\x18\x01 \x03(\x0b\x32 .yamcs.protobuf.table.ColumnData\"\\\n\nColumnInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x32\n\tenumValue\x18\x03 \x03(\x0b\x32\x1f.yamcs.protobuf.table.EnumValue\")\n\tEnumValue\x12\r\n\x05value\x18\x01 \x01(\x05\x12\r\n\x05label\x18\x02 \x01(\t\"\xc6\x02\n\tTableInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x33\n\tkeyColumn\x18\x02 \x03(\x0b\x32 .yamcs.protobuf.table.ColumnInfo\x12\x35\n\x0bvalueColumn\x18\x03 \x03(\x0b\x32 .yamcs.protobuf.table.ColumnInfo\x12\x0e\n\x06script\x18\x04 \x01(\t\x12\x17\n\x0fhistogramColumn\x18\x05 \x03(\t\x12\x15\n\rstorageEngine\x18\x06 \x01(\t\x12\x15\n\rformatVersion\x18\x07 \x01(\x05\x12\x12\n\ntablespace\x18\x08 \x01(\t\x12\x12\n\ncompressed\x18\t \x01(\x08\x12@\n\x10partitioningInfo\x18\n \x01(\x0b\x32&.yamcs.protobuf.table.PartitioningInfo\"\xf5\x01\n\x10PartitioningInfo\x12\x45\n\x04type\x18\x01 \x01(\x0e\x32\x37.yamcs.protobuf.table.PartitioningInfo.PartitioningType\x12\x12\n\ntimeColumn\x18\x02 \x01(\t\x12\x1b\n\x13timePartitionSchema\x18\x03 \x01(\t\x12\x13\n\x0bvalueColumn\x18\x04 \x01(\t\x12\x17\n\x0fvalueColumnType\x18\x05 \x01(\t\";\n\x10PartitioningType\x12\x08\n\x04TIME\x10\x01\x12\t\n\x05VALUE\x10\x02\x12\x12\n\x0eTIME_AND_VALUE\x10\x03\"o\n\nStreamInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x30\n\x06\x63olumn\x18\x02 \x03(\x0b\x32 .yamcs.protobuf.table.ColumnInfo\x12\x0e\n\x06script\x18\x03 \x01(\t\x12\x11\n\tdataCount\x18\x04 \x01(\x03\"\x8f\x01\n\x17RebuildHistogramRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\r\n\x05table\x18\x02 \x01(\t\x12)\n\x05start\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12(\n\x04stop\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x1a\n\x18RebuildHistogramResponse2\xbf\r\n\x08TableApi\x12\x83\x01\n\nExecuteSql\x12\'.yamcs.protobuf.table.ExecuteSqlRequest\x1a\x1f.yamcs.protobuf.table.ResultSet\"+\x8a\x92\x03\'\x1a\"/api/archive/{instance}:executeSql:\x01*\x12\x97\x01\n\x13\x45xecuteStreamingSql\x12\'.yamcs.protobuf.table.ExecuteSqlRequest\x1a\x1f.yamcs.protobuf.table.ResultSet\"4\x8a\x92\x03\x30\x1a+/api/archive/{instance}:executeStreamingSql:\x01*0\x01\x12\x89\x01\n\x0bListStreams\x12(.yamcs.protobuf.table.ListStreamsRequest\x1a).yamcs.protobuf.table.ListStreamsResponse\"%\x8a\x92\x03!\n\x1f/api/archive/{instance}/streams\x12\x96\x01\n\x19SubscribeStreamStatistics\x12\x36.yamcs.protobuf.table.SubscribeStreamStatisticsRequest\x1a+.yamcs.protobuf.yamcsManagement.StreamEvent\"\x12\xda\x92\x03\x0e\n\x0cstream-stats0\x01\x12\x83\x01\n\tGetStream\x12&.yamcs.protobuf.table.GetStreamRequest\x1a .yamcs.protobuf.table.StreamInfo\",\x8a\x92\x03(\n&/api/archive/{instance}/streams/{name}\x12q\n\x0fSubscribeStream\x12,.yamcs.protobuf.table.SubscribeStreamRequest\x1a .yamcs.protobuf.table.StreamData\"\x0c\xda\x92\x03\x08\n\x06stream0\x01\x12\x85\x01\n\nListTables\x12\'.yamcs.protobuf.table.ListTablesRequest\x1a(.yamcs.protobuf.table.ListTablesResponse\"$\x8a\x92\x03 \n\x1e/api/archive/{instance}/tables\x12\x7f\n\x08GetTable\x12%.yamcs.protobuf.table.GetTableRequest\x1a\x1f.yamcs.protobuf.table.TableInfo\"+\x8a\x92\x03\'\n%/api/archive/{instance}/tables/{name}\x12\x8c\x01\n\x0cGetTableData\x12).yamcs.protobuf.table.GetTableDataRequest\x1a\x1f.yamcs.protobuf.table.TableData\"0\x8a\x92\x03,\n*/api/archive/{instance}/tables/{name}/data\x12\x88\x01\n\x08ReadRows\x12%.yamcs.protobuf.table.ReadRowsRequest\x1a\x19.yamcs.protobuf.table.Row\"8\x8a\x92\x03\x34\x1a//api/archive/{instance}/tables/{table}:readRows:\x01*0\x01\x12\x9b\x01\n\tWriteRows\x12&.yamcs.protobuf.table.WriteRowsRequest\x1a\'.yamcs.protobuf.table.WriteRowsResponse\";\x8a\x92\x03\x37\x1a\x30/api/archive/{instance}/tables/{table}:writeRows:\x03row(\x01\x12\xb3\x01\n\x10RebuildHistogram\x12-.yamcs.protobuf.table.RebuildHistogramRequest\x1a..yamcs.protobuf.table.RebuildHistogramResponse\"@\x8a\x92\x03<\x1a\x37/api/archive/{instance}/tables/{table}:rebuildHistogram:\x01*B\x14\n\x12org.yamcs.protobuf')
  ,
  dependencies=[yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcs__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2.DESCRIPTOR,google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,])



_PARTITIONINGINFO_PARTITIONINGTYPE = _descriptor.EnumDescriptor(
  name='PartitioningType',
  full_name='yamcs.protobuf.table.PartitioningInfo.PartitioningType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='TIME', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VALUE', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TIME_AND_VALUE', index=2, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2377,
  serialized_end=2436,
)
_sym_db.RegisterEnumDescriptor(_PARTITIONINGINFO_PARTITIONINGTYPE)


_ROW_COLUMNINFO = _descriptor.Descriptor(
  name='ColumnInfo',
  full_name='yamcs.protobuf.table.Row.ColumnInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.table.Row.ColumnInfo.id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.Row.ColumnInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.table.Row.ColumnInfo.type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='protoClass', full_name='yamcs.protobuf.table.Row.ColumnInfo.protoClass', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=312,
  serialized_end=384,
)

_ROW_CELL = _descriptor.Descriptor(
  name='Cell',
  full_name='yamcs.protobuf.table.Row.Cell',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columnId', full_name='yamcs.protobuf.table.Row.Cell.columnId', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='data', full_name='yamcs.protobuf.table.Row.Cell.data', index=1,
      number=2, type=12, cpp_type=9, label=1,
      has_default_value=False, default_value=_b(""),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=386,
  serialized_end=424,
)

_ROW = _descriptor.Descriptor(
  name='Row',
  full_name='yamcs.protobuf.table.Row',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='yamcs.protobuf.table.Row.columns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cells', full_name='yamcs.protobuf.table.Row.cells', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_ROW_COLUMNINFO, _ROW_CELL, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=203,
  serialized_end=424,
)


_READROWSREQUEST = _descriptor.Descriptor(
  name='ReadRowsRequest',
  full_name='yamcs.protobuf.table.ReadRowsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.ReadRowsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table', full_name='yamcs.protobuf.table.ReadRowsRequest.table', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cols', full_name='yamcs.protobuf.table.ReadRowsRequest.cols', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=426,
  serialized_end=490,
)


_WRITEROWSREQUEST = _descriptor.Descriptor(
  name='WriteRowsRequest',
  full_name='yamcs.protobuf.table.WriteRowsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.WriteRowsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table', full_name='yamcs.protobuf.table.WriteRowsRequest.table', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='row', full_name='yamcs.protobuf.table.WriteRowsRequest.row', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=492,
  serialized_end=583,
)


_WRITEROWSRESPONSE = _descriptor.Descriptor(
  name='WriteRowsResponse',
  full_name='yamcs.protobuf.table.WriteRowsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='yamcs.protobuf.table.WriteRowsResponse.count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=585,
  serialized_end=619,
)


_WRITEROWSEXCEPTIONDETAIL = _descriptor.Descriptor(
  name='WriteRowsExceptionDetail',
  full_name='yamcs.protobuf.table.WriteRowsExceptionDetail',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='count', full_name='yamcs.protobuf.table.WriteRowsExceptionDetail.count', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=621,
  serialized_end=662,
)


_LISTVALUE = _descriptor.Descriptor(
  name='ListValue',
  full_name='yamcs.protobuf.table.ListValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='yamcs.protobuf.table.ListValue.values', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=664,
  serialized_end=714,
)


_EXECUTESQLREQUEST = _descriptor.Descriptor(
  name='ExecuteSqlRequest',
  full_name='yamcs.protobuf.table.ExecuteSqlRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.ExecuteSqlRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='statement', full_name='yamcs.protobuf.table.ExecuteSqlRequest.statement', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=716,
  serialized_end=772,
)


_RESULTSET = _descriptor.Descriptor(
  name='ResultSet',
  full_name='yamcs.protobuf.table.ResultSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='yamcs.protobuf.table.ResultSet.columns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='rows', full_name='yamcs.protobuf.table.ResultSet.rows', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=774,
  serialized_end=883,
)


_LISTTABLESREQUEST = _descriptor.Descriptor(
  name='ListTablesRequest',
  full_name='yamcs.protobuf.table.ListTablesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.ListTablesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=885,
  serialized_end=922,
)


_LISTTABLESRESPONSE = _descriptor.Descriptor(
  name='ListTablesResponse',
  full_name='yamcs.protobuf.table.ListTablesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='tables', full_name='yamcs.protobuf.table.ListTablesResponse.tables', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=924,
  serialized_end=993,
)


_GETTABLEREQUEST = _descriptor.Descriptor(
  name='GetTableRequest',
  full_name='yamcs.protobuf.table.GetTableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.GetTableRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.GetTableRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=995,
  serialized_end=1044,
)


_GETTABLEDATAREQUEST = _descriptor.Descriptor(
  name='GetTableDataRequest',
  full_name='yamcs.protobuf.table.GetTableDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.GetTableDataRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.GetTableDataRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cols', full_name='yamcs.protobuf.table.GetTableDataRequest.cols', index=2,
      number=3, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='pos', full_name='yamcs.protobuf.table.GetTableDataRequest.pos', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='limit', full_name='yamcs.protobuf.table.GetTableDataRequest.limit', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='order', full_name='yamcs.protobuf.table.GetTableDataRequest.order', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1046,
  serialized_end=1156,
)


_LISTSTREAMSREQUEST = _descriptor.Descriptor(
  name='ListStreamsRequest',
  full_name='yamcs.protobuf.table.ListStreamsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.ListStreamsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1158,
  serialized_end=1196,
)


_LISTSTREAMSRESPONSE = _descriptor.Descriptor(
  name='ListStreamsResponse',
  full_name='yamcs.protobuf.table.ListStreamsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='streams', full_name='yamcs.protobuf.table.ListStreamsResponse.streams', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1198,
  serialized_end=1270,
)


_GETSTREAMREQUEST = _descriptor.Descriptor(
  name='GetStreamRequest',
  full_name='yamcs.protobuf.table.GetStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.GetStreamRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.GetStreamRequest.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1272,
  serialized_end=1322,
)


_SUBSCRIBESTREAMREQUEST = _descriptor.Descriptor(
  name='SubscribeStreamRequest',
  full_name='yamcs.protobuf.table.SubscribeStreamRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.SubscribeStreamRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stream', full_name='yamcs.protobuf.table.SubscribeStreamRequest.stream', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1324,
  serialized_end=1382,
)


_COLUMNDATA = _descriptor.Descriptor(
  name='ColumnData',
  full_name='yamcs.protobuf.table.ColumnData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.ColumnData.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.table.ColumnData.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1384,
  serialized_end=1448,
)


_STREAMDATA = _descriptor.Descriptor(
  name='StreamData',
  full_name='yamcs.protobuf.table.StreamData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stream', full_name='yamcs.protobuf.table.StreamData.stream', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column', full_name='yamcs.protobuf.table.StreamData.column', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1450,
  serialized_end=1528,
)


_SUBSCRIBESTREAMSTATISTICSREQUEST = _descriptor.Descriptor(
  name='SubscribeStreamStatisticsRequest',
  full_name='yamcs.protobuf.table.SubscribeStreamStatisticsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.SubscribeStreamStatisticsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1530,
  serialized_end=1582,
)


_TABLEDATA_TABLERECORD = _descriptor.Descriptor(
  name='TableRecord',
  full_name='yamcs.protobuf.table.TableData.TableRecord',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='column', full_name='yamcs.protobuf.table.TableData.TableRecord.column', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1659,
  serialized_end=1722,
)

_TABLEDATA = _descriptor.Descriptor(
  name='TableData',
  full_name='yamcs.protobuf.table.TableData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='record', full_name='yamcs.protobuf.table.TableData.record', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_TABLEDATA_TABLERECORD, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1585,
  serialized_end=1722,
)


_COLUMNINFO = _descriptor.Descriptor(
  name='ColumnInfo',
  full_name='yamcs.protobuf.table.ColumnInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.ColumnInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.table.ColumnInfo.type', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='enumValue', full_name='yamcs.protobuf.table.ColumnInfo.enumValue', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1724,
  serialized_end=1816,
)


_ENUMVALUE = _descriptor.Descriptor(
  name='EnumValue',
  full_name='yamcs.protobuf.table.EnumValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='yamcs.protobuf.table.EnumValue.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='label', full_name='yamcs.protobuf.table.EnumValue.label', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1818,
  serialized_end=1859,
)


_TABLEINFO = _descriptor.Descriptor(
  name='TableInfo',
  full_name='yamcs.protobuf.table.TableInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.TableInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='keyColumn', full_name='yamcs.protobuf.table.TableInfo.keyColumn', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueColumn', full_name='yamcs.protobuf.table.TableInfo.valueColumn', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script', full_name='yamcs.protobuf.table.TableInfo.script', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='histogramColumn', full_name='yamcs.protobuf.table.TableInfo.histogramColumn', index=4,
      number=5, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='storageEngine', full_name='yamcs.protobuf.table.TableInfo.storageEngine', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='formatVersion', full_name='yamcs.protobuf.table.TableInfo.formatVersion', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='tablespace', full_name='yamcs.protobuf.table.TableInfo.tablespace', index=7,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='compressed', full_name='yamcs.protobuf.table.TableInfo.compressed', index=8,
      number=9, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='partitioningInfo', full_name='yamcs.protobuf.table.TableInfo.partitioningInfo', index=9,
      number=10, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1862,
  serialized_end=2188,
)


_PARTITIONINGINFO = _descriptor.Descriptor(
  name='PartitioningInfo',
  full_name='yamcs.protobuf.table.PartitioningInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='yamcs.protobuf.table.PartitioningInfo.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timeColumn', full_name='yamcs.protobuf.table.PartitioningInfo.timeColumn', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='timePartitionSchema', full_name='yamcs.protobuf.table.PartitioningInfo.timePartitionSchema', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueColumn', full_name='yamcs.protobuf.table.PartitioningInfo.valueColumn', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='valueColumnType', full_name='yamcs.protobuf.table.PartitioningInfo.valueColumnType', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _PARTITIONINGINFO_PARTITIONINGTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2191,
  serialized_end=2436,
)


_STREAMINFO = _descriptor.Descriptor(
  name='StreamInfo',
  full_name='yamcs.protobuf.table.StreamInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.table.StreamInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='column', full_name='yamcs.protobuf.table.StreamInfo.column', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='script', full_name='yamcs.protobuf.table.StreamInfo.script', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='dataCount', full_name='yamcs.protobuf.table.StreamInfo.dataCount', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2438,
  serialized_end=2549,
)


_REBUILDHISTOGRAMREQUEST = _descriptor.Descriptor(
  name='RebuildHistogramRequest',
  full_name='yamcs.protobuf.table.RebuildHistogramRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.table.RebuildHistogramRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='table', full_name='yamcs.protobuf.table.RebuildHistogramRequest.table', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start', full_name='yamcs.protobuf.table.RebuildHistogramRequest.start', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stop', full_name='yamcs.protobuf.table.RebuildHistogramRequest.stop', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2552,
  serialized_end=2695,
)


_REBUILDHISTOGRAMRESPONSE = _descriptor.Descriptor(
  name='RebuildHistogramResponse',
  full_name='yamcs.protobuf.table.RebuildHistogramResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2697,
  serialized_end=2723,
)

_ROW_COLUMNINFO.containing_type = _ROW
_ROW_CELL.containing_type = _ROW
_ROW.fields_by_name['columns'].message_type = _ROW_COLUMNINFO
_ROW.fields_by_name['cells'].message_type = _ROW_CELL
_WRITEROWSREQUEST.fields_by_name['row'].message_type = _ROW
_LISTVALUE.fields_by_name['values'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_RESULTSET.fields_by_name['columns'].message_type = _COLUMNINFO
_RESULTSET.fields_by_name['rows'].message_type = _LISTVALUE
_LISTTABLESRESPONSE.fields_by_name['tables'].message_type = _TABLEINFO
_LISTSTREAMSRESPONSE.fields_by_name['streams'].message_type = _STREAMINFO
_COLUMNDATA.fields_by_name['value'].message_type = yamcs_dot_protobuf_dot_yamcs__pb2._VALUE
_STREAMDATA.fields_by_name['column'].message_type = _COLUMNDATA
_TABLEDATA_TABLERECORD.fields_by_name['column'].message_type = _COLUMNDATA
_TABLEDATA_TABLERECORD.containing_type = _TABLEDATA
_TABLEDATA.fields_by_name['record'].message_type = _TABLEDATA_TABLERECORD
_COLUMNINFO.fields_by_name['enumValue'].message_type = _ENUMVALUE
_TABLEINFO.fields_by_name['keyColumn'].message_type = _COLUMNINFO
_TABLEINFO.fields_by_name['valueColumn'].message_type = _COLUMNINFO
_TABLEINFO.fields_by_name['partitioningInfo'].message_type = _PARTITIONINGINFO
_PARTITIONINGINFO.fields_by_name['type'].enum_type = _PARTITIONINGINFO_PARTITIONINGTYPE
_PARTITIONINGINFO_PARTITIONINGTYPE.containing_type = _PARTITIONINGINFO
_STREAMINFO.fields_by_name['column'].message_type = _COLUMNINFO
_REBUILDHISTOGRAMREQUEST.fields_by_name['start'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_REBUILDHISTOGRAMREQUEST.fields_by_name['stop'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
DESCRIPTOR.message_types_by_name['Row'] = _ROW
DESCRIPTOR.message_types_by_name['ReadRowsRequest'] = _READROWSREQUEST
DESCRIPTOR.message_types_by_name['WriteRowsRequest'] = _WRITEROWSREQUEST
DESCRIPTOR.message_types_by_name['WriteRowsResponse'] = _WRITEROWSRESPONSE
DESCRIPTOR.message_types_by_name['WriteRowsExceptionDetail'] = _WRITEROWSEXCEPTIONDETAIL
DESCRIPTOR.message_types_by_name['ListValue'] = _LISTVALUE
DESCRIPTOR.message_types_by_name['ExecuteSqlRequest'] = _EXECUTESQLREQUEST
DESCRIPTOR.message_types_by_name['ResultSet'] = _RESULTSET
DESCRIPTOR.message_types_by_name['ListTablesRequest'] = _LISTTABLESREQUEST
DESCRIPTOR.message_types_by_name['ListTablesResponse'] = _LISTTABLESRESPONSE
DESCRIPTOR.message_types_by_name['GetTableRequest'] = _GETTABLEREQUEST
DESCRIPTOR.message_types_by_name['GetTableDataRequest'] = _GETTABLEDATAREQUEST
DESCRIPTOR.message_types_by_name['ListStreamsRequest'] = _LISTSTREAMSREQUEST
DESCRIPTOR.message_types_by_name['ListStreamsResponse'] = _LISTSTREAMSRESPONSE
DESCRIPTOR.message_types_by_name['GetStreamRequest'] = _GETSTREAMREQUEST
DESCRIPTOR.message_types_by_name['SubscribeStreamRequest'] = _SUBSCRIBESTREAMREQUEST
DESCRIPTOR.message_types_by_name['ColumnData'] = _COLUMNDATA
DESCRIPTOR.message_types_by_name['StreamData'] = _STREAMDATA
DESCRIPTOR.message_types_by_name['SubscribeStreamStatisticsRequest'] = _SUBSCRIBESTREAMSTATISTICSREQUEST
DESCRIPTOR.message_types_by_name['TableData'] = _TABLEDATA
DESCRIPTOR.message_types_by_name['ColumnInfo'] = _COLUMNINFO
DESCRIPTOR.message_types_by_name['EnumValue'] = _ENUMVALUE
DESCRIPTOR.message_types_by_name['TableInfo'] = _TABLEINFO
DESCRIPTOR.message_types_by_name['PartitioningInfo'] = _PARTITIONINGINFO
DESCRIPTOR.message_types_by_name['StreamInfo'] = _STREAMINFO
DESCRIPTOR.message_types_by_name['RebuildHistogramRequest'] = _REBUILDHISTOGRAMREQUEST
DESCRIPTOR.message_types_by_name['RebuildHistogramResponse'] = _REBUILDHISTOGRAMRESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Row = _reflection.GeneratedProtocolMessageType('Row', (_message.Message,), dict(

  ColumnInfo = _reflection.GeneratedProtocolMessageType('ColumnInfo', (_message.Message,), dict(
    DESCRIPTOR = _ROW_COLUMNINFO,
    __module__ = 'yamcs.protobuf.table.table_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.Row.ColumnInfo)
    ))
  ,

  Cell = _reflection.GeneratedProtocolMessageType('Cell', (_message.Message,), dict(
    DESCRIPTOR = _ROW_CELL,
    __module__ = 'yamcs.protobuf.table.table_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.Row.Cell)
    ))
  ,
  DESCRIPTOR = _ROW,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.Row)
  ))
_sym_db.RegisterMessage(Row)
_sym_db.RegisterMessage(Row.ColumnInfo)
_sym_db.RegisterMessage(Row.Cell)

ReadRowsRequest = _reflection.GeneratedProtocolMessageType('ReadRowsRequest', (_message.Message,), dict(
  DESCRIPTOR = _READROWSREQUEST,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ReadRowsRequest)
  ))
_sym_db.RegisterMessage(ReadRowsRequest)

WriteRowsRequest = _reflection.GeneratedProtocolMessageType('WriteRowsRequest', (_message.Message,), dict(
  DESCRIPTOR = _WRITEROWSREQUEST,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.WriteRowsRequest)
  ))
_sym_db.RegisterMessage(WriteRowsRequest)

WriteRowsResponse = _reflection.GeneratedProtocolMessageType('WriteRowsResponse', (_message.Message,), dict(
  DESCRIPTOR = _WRITEROWSRESPONSE,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.WriteRowsResponse)
  ))
_sym_db.RegisterMessage(WriteRowsResponse)

WriteRowsExceptionDetail = _reflection.GeneratedProtocolMessageType('WriteRowsExceptionDetail', (_message.Message,), dict(
  DESCRIPTOR = _WRITEROWSEXCEPTIONDETAIL,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.WriteRowsExceptionDetail)
  ))
_sym_db.RegisterMessage(WriteRowsExceptionDetail)

ListValue = _reflection.GeneratedProtocolMessageType('ListValue', (_message.Message,), dict(
  DESCRIPTOR = _LISTVALUE,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ListValue)
  ))
_sym_db.RegisterMessage(ListValue)

ExecuteSqlRequest = _reflection.GeneratedProtocolMessageType('ExecuteSqlRequest', (_message.Message,), dict(
  DESCRIPTOR = _EXECUTESQLREQUEST,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ExecuteSqlRequest)
  ))
_sym_db.RegisterMessage(ExecuteSqlRequest)

ResultSet = _reflection.GeneratedProtocolMessageType('ResultSet', (_message.Message,), dict(
  DESCRIPTOR = _RESULTSET,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ResultSet)
  ))
_sym_db.RegisterMessage(ResultSet)

ListTablesRequest = _reflection.GeneratedProtocolMessageType('ListTablesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTTABLESREQUEST,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ListTablesRequest)
  ))
_sym_db.RegisterMessage(ListTablesRequest)

ListTablesResponse = _reflection.GeneratedProtocolMessageType('ListTablesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTTABLESRESPONSE,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ListTablesResponse)
  ))
_sym_db.RegisterMessage(ListTablesResponse)

GetTableRequest = _reflection.GeneratedProtocolMessageType('GetTableRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTABLEREQUEST,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.GetTableRequest)
  ))
_sym_db.RegisterMessage(GetTableRequest)

GetTableDataRequest = _reflection.GeneratedProtocolMessageType('GetTableDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTABLEDATAREQUEST,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.GetTableDataRequest)
  ))
_sym_db.RegisterMessage(GetTableDataRequest)

ListStreamsRequest = _reflection.GeneratedProtocolMessageType('ListStreamsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTSTREAMSREQUEST,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ListStreamsRequest)
  ))
_sym_db.RegisterMessage(ListStreamsRequest)

ListStreamsResponse = _reflection.GeneratedProtocolMessageType('ListStreamsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTSTREAMSRESPONSE,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ListStreamsResponse)
  ))
_sym_db.RegisterMessage(ListStreamsResponse)

GetStreamRequest = _reflection.GeneratedProtocolMessageType('GetStreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETSTREAMREQUEST,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.GetStreamRequest)
  ))
_sym_db.RegisterMessage(GetStreamRequest)

SubscribeStreamRequest = _reflection.GeneratedProtocolMessageType('SubscribeStreamRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBESTREAMREQUEST,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.SubscribeStreamRequest)
  ))
_sym_db.RegisterMessage(SubscribeStreamRequest)

ColumnData = _reflection.GeneratedProtocolMessageType('ColumnData', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNDATA,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ColumnData)
  ))
_sym_db.RegisterMessage(ColumnData)

StreamData = _reflection.GeneratedProtocolMessageType('StreamData', (_message.Message,), dict(
  DESCRIPTOR = _STREAMDATA,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.StreamData)
  ))
_sym_db.RegisterMessage(StreamData)

SubscribeStreamStatisticsRequest = _reflection.GeneratedProtocolMessageType('SubscribeStreamStatisticsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBESTREAMSTATISTICSREQUEST,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.SubscribeStreamStatisticsRequest)
  ))
_sym_db.RegisterMessage(SubscribeStreamStatisticsRequest)

TableData = _reflection.GeneratedProtocolMessageType('TableData', (_message.Message,), dict(

  TableRecord = _reflection.GeneratedProtocolMessageType('TableRecord', (_message.Message,), dict(
    DESCRIPTOR = _TABLEDATA_TABLERECORD,
    __module__ = 'yamcs.protobuf.table.table_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.TableData.TableRecord)
    ))
  ,
  DESCRIPTOR = _TABLEDATA,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.TableData)
  ))
_sym_db.RegisterMessage(TableData)
_sym_db.RegisterMessage(TableData.TableRecord)

ColumnInfo = _reflection.GeneratedProtocolMessageType('ColumnInfo', (_message.Message,), dict(
  DESCRIPTOR = _COLUMNINFO,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.ColumnInfo)
  ))
_sym_db.RegisterMessage(ColumnInfo)

EnumValue = _reflection.GeneratedProtocolMessageType('EnumValue', (_message.Message,), dict(
  DESCRIPTOR = _ENUMVALUE,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.EnumValue)
  ))
_sym_db.RegisterMessage(EnumValue)

TableInfo = _reflection.GeneratedProtocolMessageType('TableInfo', (_message.Message,), dict(
  DESCRIPTOR = _TABLEINFO,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.TableInfo)
  ))
_sym_db.RegisterMessage(TableInfo)

PartitioningInfo = _reflection.GeneratedProtocolMessageType('PartitioningInfo', (_message.Message,), dict(
  DESCRIPTOR = _PARTITIONINGINFO,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.PartitioningInfo)
  ))
_sym_db.RegisterMessage(PartitioningInfo)

StreamInfo = _reflection.GeneratedProtocolMessageType('StreamInfo', (_message.Message,), dict(
  DESCRIPTOR = _STREAMINFO,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.StreamInfo)
  ))
_sym_db.RegisterMessage(StreamInfo)

RebuildHistogramRequest = _reflection.GeneratedProtocolMessageType('RebuildHistogramRequest', (_message.Message,), dict(
  DESCRIPTOR = _REBUILDHISTOGRAMREQUEST,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.RebuildHistogramRequest)
  ))
_sym_db.RegisterMessage(RebuildHistogramRequest)

RebuildHistogramResponse = _reflection.GeneratedProtocolMessageType('RebuildHistogramResponse', (_message.Message,), dict(
  DESCRIPTOR = _REBUILDHISTOGRAMRESPONSE,
  __module__ = 'yamcs.protobuf.table.table_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.table.RebuildHistogramResponse)
  ))
_sym_db.RegisterMessage(RebuildHistogramResponse)


DESCRIPTOR._options = None

_TABLEAPI = _descriptor.ServiceDescriptor(
  name='TableApi',
  full_name='yamcs.protobuf.table.TableApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2726,
  serialized_end=4453,
  methods=[
  _descriptor.MethodDescriptor(
    name='ExecuteSql',
    full_name='yamcs.protobuf.table.TableApi.ExecuteSql',
    index=0,
    containing_service=None,
    input_type=_EXECUTESQLREQUEST,
    output_type=_RESULTSET,
    serialized_options=_b('\212\222\003\'\032\"/api/archive/{instance}:executeSql:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ExecuteStreamingSql',
    full_name='yamcs.protobuf.table.TableApi.ExecuteStreamingSql',
    index=1,
    containing_service=None,
    input_type=_EXECUTESQLREQUEST,
    output_type=_RESULTSET,
    serialized_options=_b('\212\222\0030\032+/api/archive/{instance}:executeStreamingSql:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='ListStreams',
    full_name='yamcs.protobuf.table.TableApi.ListStreams',
    index=2,
    containing_service=None,
    input_type=_LISTSTREAMSREQUEST,
    output_type=_LISTSTREAMSRESPONSE,
    serialized_options=_b('\212\222\003!\n\037/api/archive/{instance}/streams'),
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeStreamStatistics',
    full_name='yamcs.protobuf.table.TableApi.SubscribeStreamStatistics',
    index=3,
    containing_service=None,
    input_type=_SUBSCRIBESTREAMSTATISTICSREQUEST,
    output_type=yamcs_dot_protobuf_dot_yamcsManagement_dot_yamcsManagement__pb2._STREAMEVENT,
    serialized_options=_b('\332\222\003\016\n\014stream-stats'),
  ),
  _descriptor.MethodDescriptor(
    name='GetStream',
    full_name='yamcs.protobuf.table.TableApi.GetStream',
    index=4,
    containing_service=None,
    input_type=_GETSTREAMREQUEST,
    output_type=_STREAMINFO,
    serialized_options=_b('\212\222\003(\n&/api/archive/{instance}/streams/{name}'),
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeStream',
    full_name='yamcs.protobuf.table.TableApi.SubscribeStream',
    index=5,
    containing_service=None,
    input_type=_SUBSCRIBESTREAMREQUEST,
    output_type=_STREAMDATA,
    serialized_options=_b('\332\222\003\010\n\006stream'),
  ),
  _descriptor.MethodDescriptor(
    name='ListTables',
    full_name='yamcs.protobuf.table.TableApi.ListTables',
    index=6,
    containing_service=None,
    input_type=_LISTTABLESREQUEST,
    output_type=_LISTTABLESRESPONSE,
    serialized_options=_b('\212\222\003 \n\036/api/archive/{instance}/tables'),
  ),
  _descriptor.MethodDescriptor(
    name='GetTable',
    full_name='yamcs.protobuf.table.TableApi.GetTable',
    index=7,
    containing_service=None,
    input_type=_GETTABLEREQUEST,
    output_type=_TABLEINFO,
    serialized_options=_b('\212\222\003\'\n%/api/archive/{instance}/tables/{name}'),
  ),
  _descriptor.MethodDescriptor(
    name='GetTableData',
    full_name='yamcs.protobuf.table.TableApi.GetTableData',
    index=8,
    containing_service=None,
    input_type=_GETTABLEDATAREQUEST,
    output_type=_TABLEDATA,
    serialized_options=_b('\212\222\003,\n*/api/archive/{instance}/tables/{name}/data'),
  ),
  _descriptor.MethodDescriptor(
    name='ReadRows',
    full_name='yamcs.protobuf.table.TableApi.ReadRows',
    index=9,
    containing_service=None,
    input_type=_READROWSREQUEST,
    output_type=_ROW,
    serialized_options=_b('\212\222\0034\032//api/archive/{instance}/tables/{table}:readRows:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='WriteRows',
    full_name='yamcs.protobuf.table.TableApi.WriteRows',
    index=10,
    containing_service=None,
    input_type=_WRITEROWSREQUEST,
    output_type=_WRITEROWSRESPONSE,
    serialized_options=_b('\212\222\0037\0320/api/archive/{instance}/tables/{table}:writeRows:\003row'),
  ),
  _descriptor.MethodDescriptor(
    name='RebuildHistogram',
    full_name='yamcs.protobuf.table.TableApi.RebuildHistogram',
    index=11,
    containing_service=None,
    input_type=_REBUILDHISTOGRAMREQUEST,
    output_type=_REBUILDHISTOGRAMRESPONSE,
    serialized_options=_b('\212\222\003<\0327/api/archive/{instance}/tables/{table}:rebuildHistogram:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_TABLEAPI)

DESCRIPTOR.services_by_name['TableApi'] = _TABLEAPI

# @@protoc_insertion_point(module_scope)
