# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/commanding/queue_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2
from yamcs.protobuf.commanding import commanding_pb2 as yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/commanding/queue_service.proto',
  package='yamcs.protobuf.commanding',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\021QueueServiceProtoP\001'),
  serialized_pb=_b('\n-yamcs/protobuf/commanding/queue_service.proto\x12\x19yamcs.protobuf.commanding\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\x1a*yamcs/protobuf/commanding/commanding.proto\"8\n\x11ListQueuesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"Q\n\x12ListQueuesResponse\x12;\n\x06queues\x18\x01 \x03(\x0b\x32+.yamcs.protobuf.commanding.CommandQueueInfo\"F\n\x1fSubscribeQueueStatisticsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"B\n\x1bSubscribeQueueEventsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\"E\n\x0fGetQueueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05queue\x18\x03 \x01(\t\"U\n\x10\x45\x64itQueueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05queue\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\"H\n\x12\x45nableQueueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05queue\x18\x03 \x01(\t\"I\n\x13\x44isableQueueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05queue\x18\x03 \x01(\t\"G\n\x11\x42lockQueueRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05queue\x18\x03 \x01(\t\"O\n\x19ListQueuedCommandsRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05queue\x18\x03 \x01(\t\"\\\n\x1aListQueuedCommandsResponse\x12>\n\x08\x63ommands\x18\x01 \x03(\x0b\x32,.yamcs.protobuf.commanding.CommandQueueEntry\"h\n\x15\x45\x64itQueueEntryRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05queue\x18\x03 \x01(\t\x12\x0c\n\x04uuid\x18\x04 \x01(\t\x12\r\n\x05state\x18\x05 \x01(\t\"[\n\x14\x41\x63\x63\x65ptCommandRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05queue\x18\x03 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\"[\n\x14RejectCommandRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\r\n\x05queue\x18\x03 \x01(\t\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t2\xfb\x11\n\x08QueueApi\x12\x9e\x01\n\nListQueues\x12,.yamcs.protobuf.commanding.ListQueuesRequest\x1a-.yamcs.protobuf.commanding.ListQueuesResponse\"3\x8a\x92\x03/\n-/api/processors/{instance}/{processor}/queues\x12\xa0\x01\n\x08GetQueue\x12*.yamcs.protobuf.commanding.GetQueueRequest\x1a+.yamcs.protobuf.commanding.CommandQueueInfo\";\x8a\x92\x03\x37\n5/api/processors/{instance}/{processor}/queues/{queue}\x12\xa9\x01\n\x0bUpdateQueue\x12+.yamcs.protobuf.commanding.EditQueueRequest\x1a+.yamcs.protobuf.commanding.CommandQueueInfo\"@\x8a\x92\x03<*5/api/processors/{instance}/{processor}/queues/{queue}0\x01:\x01*\x12\xe2\x01\n\x0b\x45nableQueue\x12-.yamcs.protobuf.commanding.EnableQueueRequest\x1a+.yamcs.protobuf.commanding.CommandQueueInfo\"w\x8a\x92\x03s\x1a</api/processors/{instance}/{processor}/queues/{queue}:enableb3Queue \'{queue}\' enabled for processor \'{processor}\'\x12\xe6\x01\n\x0c\x44isableQueue\x12..yamcs.protobuf.commanding.DisableQueueRequest\x1a+.yamcs.protobuf.commanding.CommandQueueInfo\"y\x8a\x92\x03u\x1a=/api/processors/{instance}/{processor}/queues/{queue}:disableb4Queue \'{queue}\' disabled for processor \'{processor}\'\x12\xdf\x01\n\nBlockQueue\x12,.yamcs.protobuf.commanding.BlockQueueRequest\x1a+.yamcs.protobuf.commanding.CommandQueueInfo\"v\x8a\x92\x03r\x1a;/api/processors/{instance}/{processor}/queues/{queue}:blockb3Queue \'{queue}\' blocked for processor \'{processor}\'\x12\x98\x01\n\x18SubscribeQueueStatistics\x12:.yamcs.protobuf.commanding.SubscribeQueueStatisticsRequest\x1a+.yamcs.protobuf.commanding.CommandQueueInfo\"\x11\xda\x92\x03\r\n\x0bqueue-stats0\x01\x12\x92\x01\n\x14SubscribeQueueEvents\x12\x36.yamcs.protobuf.commanding.SubscribeQueueEventsRequest\x1a,.yamcs.protobuf.commanding.CommandQueueEvent\"\x12\xda\x92\x03\x0e\n\x0cqueue-events0\x01\x12\x8a\x02\n\x12ListQueuedCommands\x12\x34.yamcs.protobuf.commanding.ListQueuedCommandsRequest\x1a\x35.yamcs.protobuf.commanding.ListQueuedCommandsResponse\"\x86\x01\x8a\x92\x03\x81\x01\n>/api/processors/{instance}/{processor}/queues/{queue}/commandsZ?\n=/api/processors/{instance}/{processor}/queues/{queue}/entries\x12\xad\x01\n\x10UpdateQueueEntry\x12\x30.yamcs.protobuf.commanding.EditQueueEntryRequest\x1a\x16.google.protobuf.Empty\"O\x8a\x92\x03K*D/api/processors/{instance}/{processor}/queues/{queue}/entries/{uuid}0\x01:\x01*\x12\xaf\x01\n\rAcceptCommand\x12/.yamcs.protobuf.commanding.AcceptCommandRequest\x1a\x16.google.protobuf.Empty\"U\x8a\x92\x03Q\x1aO/api/processors/{instance}/{processor}/queues/{queue}/commands/{command}:accept\x12\xaf\x01\n\rRejectCommand\x12/.yamcs.protobuf.commanding.RejectCommandRequest\x1a\x16.google.protobuf.Empty\"U\x8a\x92\x03Q\x1aO/api/processors/{instance}/{processor}/queues/{queue}/commands/{command}:rejectB)\n\x12org.yamcs.protobufB\x11QueueServiceProtoP\x01')
  ,
  dependencies=[google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2.DESCRIPTOR,])




_LISTQUEUESREQUEST = _descriptor.Descriptor(
  name='ListQueuesRequest',
  full_name='yamcs.protobuf.commanding.ListQueuesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.ListQueuesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.ListQueuesRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=178,
  serialized_end=234,
)


_LISTQUEUESRESPONSE = _descriptor.Descriptor(
  name='ListQueuesResponse',
  full_name='yamcs.protobuf.commanding.ListQueuesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='queues', full_name='yamcs.protobuf.commanding.ListQueuesResponse.queues', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=317,
)


_SUBSCRIBEQUEUESTATISTICSREQUEST = _descriptor.Descriptor(
  name='SubscribeQueueStatisticsRequest',
  full_name='yamcs.protobuf.commanding.SubscribeQueueStatisticsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.SubscribeQueueStatisticsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.SubscribeQueueStatisticsRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=319,
  serialized_end=389,
)


_SUBSCRIBEQUEUEEVENTSREQUEST = _descriptor.Descriptor(
  name='SubscribeQueueEventsRequest',
  full_name='yamcs.protobuf.commanding.SubscribeQueueEventsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.SubscribeQueueEventsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.SubscribeQueueEventsRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=391,
  serialized_end=457,
)


_GETQUEUEREQUEST = _descriptor.Descriptor(
  name='GetQueueRequest',
  full_name='yamcs.protobuf.commanding.GetQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.GetQueueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.GetQueueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.GetQueueRequest.queue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=459,
  serialized_end=528,
)


_EDITQUEUEREQUEST = _descriptor.Descriptor(
  name='EditQueueRequest',
  full_name='yamcs.protobuf.commanding.EditQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.EditQueueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.EditQueueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.EditQueueRequest.queue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.commanding.EditQueueRequest.state', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=530,
  serialized_end=615,
)


_ENABLEQUEUEREQUEST = _descriptor.Descriptor(
  name='EnableQueueRequest',
  full_name='yamcs.protobuf.commanding.EnableQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.EnableQueueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.EnableQueueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.EnableQueueRequest.queue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=617,
  serialized_end=689,
)


_DISABLEQUEUEREQUEST = _descriptor.Descriptor(
  name='DisableQueueRequest',
  full_name='yamcs.protobuf.commanding.DisableQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.DisableQueueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.DisableQueueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.DisableQueueRequest.queue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=691,
  serialized_end=764,
)


_BLOCKQUEUEREQUEST = _descriptor.Descriptor(
  name='BlockQueueRequest',
  full_name='yamcs.protobuf.commanding.BlockQueueRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.BlockQueueRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.BlockQueueRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.BlockQueueRequest.queue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=837,
)


_LISTQUEUEDCOMMANDSREQUEST = _descriptor.Descriptor(
  name='ListQueuedCommandsRequest',
  full_name='yamcs.protobuf.commanding.ListQueuedCommandsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.ListQueuedCommandsRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.ListQueuedCommandsRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.ListQueuedCommandsRequest.queue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=839,
  serialized_end=918,
)


_LISTQUEUEDCOMMANDSRESPONSE = _descriptor.Descriptor(
  name='ListQueuedCommandsResponse',
  full_name='yamcs.protobuf.commanding.ListQueuedCommandsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='commands', full_name='yamcs.protobuf.commanding.ListQueuedCommandsResponse.commands', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=920,
  serialized_end=1012,
)


_EDITQUEUEENTRYREQUEST = _descriptor.Descriptor(
  name='EditQueueEntryRequest',
  full_name='yamcs.protobuf.commanding.EditQueueEntryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.queue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uuid', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.uuid', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.commanding.EditQueueEntryRequest.state', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1014,
  serialized_end=1118,
)


_ACCEPTCOMMANDREQUEST = _descriptor.Descriptor(
  name='AcceptCommandRequest',
  full_name='yamcs.protobuf.commanding.AcceptCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.AcceptCommandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.AcceptCommandRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.AcceptCommandRequest.queue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='yamcs.protobuf.commanding.AcceptCommandRequest.command', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1120,
  serialized_end=1211,
)


_REJECTCOMMANDREQUEST = _descriptor.Descriptor(
  name='RejectCommandRequest',
  full_name='yamcs.protobuf.commanding.RejectCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.commanding.RejectCommandRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='processor', full_name='yamcs.protobuf.commanding.RejectCommandRequest.processor', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='queue', full_name='yamcs.protobuf.commanding.RejectCommandRequest.queue', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='command', full_name='yamcs.protobuf.commanding.RejectCommandRequest.command', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1213,
  serialized_end=1304,
)

_LISTQUEUESRESPONSE.fields_by_name['queues'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO
_LISTQUEUEDCOMMANDSRESPONSE.fields_by_name['commands'].message_type = yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEENTRY
DESCRIPTOR.message_types_by_name['ListQueuesRequest'] = _LISTQUEUESREQUEST
DESCRIPTOR.message_types_by_name['ListQueuesResponse'] = _LISTQUEUESRESPONSE
DESCRIPTOR.message_types_by_name['SubscribeQueueStatisticsRequest'] = _SUBSCRIBEQUEUESTATISTICSREQUEST
DESCRIPTOR.message_types_by_name['SubscribeQueueEventsRequest'] = _SUBSCRIBEQUEUEEVENTSREQUEST
DESCRIPTOR.message_types_by_name['GetQueueRequest'] = _GETQUEUEREQUEST
DESCRIPTOR.message_types_by_name['EditQueueRequest'] = _EDITQUEUEREQUEST
DESCRIPTOR.message_types_by_name['EnableQueueRequest'] = _ENABLEQUEUEREQUEST
DESCRIPTOR.message_types_by_name['DisableQueueRequest'] = _DISABLEQUEUEREQUEST
DESCRIPTOR.message_types_by_name['BlockQueueRequest'] = _BLOCKQUEUEREQUEST
DESCRIPTOR.message_types_by_name['ListQueuedCommandsRequest'] = _LISTQUEUEDCOMMANDSREQUEST
DESCRIPTOR.message_types_by_name['ListQueuedCommandsResponse'] = _LISTQUEUEDCOMMANDSRESPONSE
DESCRIPTOR.message_types_by_name['EditQueueEntryRequest'] = _EDITQUEUEENTRYREQUEST
DESCRIPTOR.message_types_by_name['AcceptCommandRequest'] = _ACCEPTCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['RejectCommandRequest'] = _REJECTCOMMANDREQUEST
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

ListQueuesRequest = _reflection.GeneratedProtocolMessageType('ListQueuesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTQUEUESREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueuesRequest)
  ))
_sym_db.RegisterMessage(ListQueuesRequest)

ListQueuesResponse = _reflection.GeneratedProtocolMessageType('ListQueuesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTQUEUESRESPONSE,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueuesResponse)
  ))
_sym_db.RegisterMessage(ListQueuesResponse)

SubscribeQueueStatisticsRequest = _reflection.GeneratedProtocolMessageType('SubscribeQueueStatisticsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEQUEUESTATISTICSREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.SubscribeQueueStatisticsRequest)
  ))
_sym_db.RegisterMessage(SubscribeQueueStatisticsRequest)

SubscribeQueueEventsRequest = _reflection.GeneratedProtocolMessageType('SubscribeQueueEventsRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBEQUEUEEVENTSREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.SubscribeQueueEventsRequest)
  ))
_sym_db.RegisterMessage(SubscribeQueueEventsRequest)

GetQueueRequest = _reflection.GeneratedProtocolMessageType('GetQueueRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETQUEUEREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.GetQueueRequest)
  ))
_sym_db.RegisterMessage(GetQueueRequest)

EditQueueRequest = _reflection.GeneratedProtocolMessageType('EditQueueRequest', (_message.Message,), dict(
  DESCRIPTOR = _EDITQUEUEREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.EditQueueRequest)
  ))
_sym_db.RegisterMessage(EditQueueRequest)

EnableQueueRequest = _reflection.GeneratedProtocolMessageType('EnableQueueRequest', (_message.Message,), dict(
  DESCRIPTOR = _ENABLEQUEUEREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.EnableQueueRequest)
  ))
_sym_db.RegisterMessage(EnableQueueRequest)

DisableQueueRequest = _reflection.GeneratedProtocolMessageType('DisableQueueRequest', (_message.Message,), dict(
  DESCRIPTOR = _DISABLEQUEUEREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.DisableQueueRequest)
  ))
_sym_db.RegisterMessage(DisableQueueRequest)

BlockQueueRequest = _reflection.GeneratedProtocolMessageType('BlockQueueRequest', (_message.Message,), dict(
  DESCRIPTOR = _BLOCKQUEUEREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.BlockQueueRequest)
  ))
_sym_db.RegisterMessage(BlockQueueRequest)

ListQueuedCommandsRequest = _reflection.GeneratedProtocolMessageType('ListQueuedCommandsRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTQUEUEDCOMMANDSREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueuedCommandsRequest)
  ))
_sym_db.RegisterMessage(ListQueuedCommandsRequest)

ListQueuedCommandsResponse = _reflection.GeneratedProtocolMessageType('ListQueuedCommandsResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTQUEUEDCOMMANDSRESPONSE,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.ListQueuedCommandsResponse)
  ))
_sym_db.RegisterMessage(ListQueuedCommandsResponse)

EditQueueEntryRequest = _reflection.GeneratedProtocolMessageType('EditQueueEntryRequest', (_message.Message,), dict(
  DESCRIPTOR = _EDITQUEUEENTRYREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.EditQueueEntryRequest)
  ))
_sym_db.RegisterMessage(EditQueueEntryRequest)

AcceptCommandRequest = _reflection.GeneratedProtocolMessageType('AcceptCommandRequest', (_message.Message,), dict(
  DESCRIPTOR = _ACCEPTCOMMANDREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.AcceptCommandRequest)
  ))
_sym_db.RegisterMessage(AcceptCommandRequest)

RejectCommandRequest = _reflection.GeneratedProtocolMessageType('RejectCommandRequest', (_message.Message,), dict(
  DESCRIPTOR = _REJECTCOMMANDREQUEST,
  __module__ = 'yamcs.protobuf.commanding.queue_service_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.commanding.RejectCommandRequest)
  ))
_sym_db.RegisterMessage(RejectCommandRequest)


DESCRIPTOR._options = None

_QUEUEAPI = _descriptor.ServiceDescriptor(
  name='QueueApi',
  full_name='yamcs.protobuf.commanding.QueueApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1307,
  serialized_end=3606,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListQueues',
    full_name='yamcs.protobuf.commanding.QueueApi.ListQueues',
    index=0,
    containing_service=None,
    input_type=_LISTQUEUESREQUEST,
    output_type=_LISTQUEUESRESPONSE,
    serialized_options=_b('\212\222\003/\n-/api/processors/{instance}/{processor}/queues'),
  ),
  _descriptor.MethodDescriptor(
    name='GetQueue',
    full_name='yamcs.protobuf.commanding.QueueApi.GetQueue',
    index=1,
    containing_service=None,
    input_type=_GETQUEUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO,
    serialized_options=_b('\212\222\0037\n5/api/processors/{instance}/{processor}/queues/{queue}'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateQueue',
    full_name='yamcs.protobuf.commanding.QueueApi.UpdateQueue',
    index=2,
    containing_service=None,
    input_type=_EDITQUEUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO,
    serialized_options=_b('\212\222\003<*5/api/processors/{instance}/{processor}/queues/{queue}0\001:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='EnableQueue',
    full_name='yamcs.protobuf.commanding.QueueApi.EnableQueue',
    index=3,
    containing_service=None,
    input_type=_ENABLEQUEUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO,
    serialized_options=_b('\212\222\003s\032</api/processors/{instance}/{processor}/queues/{queue}:enableb3Queue \'{queue}\' enabled for processor \'{processor}\''),
  ),
  _descriptor.MethodDescriptor(
    name='DisableQueue',
    full_name='yamcs.protobuf.commanding.QueueApi.DisableQueue',
    index=4,
    containing_service=None,
    input_type=_DISABLEQUEUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO,
    serialized_options=_b('\212\222\003u\032=/api/processors/{instance}/{processor}/queues/{queue}:disableb4Queue \'{queue}\' disabled for processor \'{processor}\''),
  ),
  _descriptor.MethodDescriptor(
    name='BlockQueue',
    full_name='yamcs.protobuf.commanding.QueueApi.BlockQueue',
    index=5,
    containing_service=None,
    input_type=_BLOCKQUEUEREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO,
    serialized_options=_b('\212\222\003r\032;/api/processors/{instance}/{processor}/queues/{queue}:blockb3Queue \'{queue}\' blocked for processor \'{processor}\''),
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeQueueStatistics',
    full_name='yamcs.protobuf.commanding.QueueApi.SubscribeQueueStatistics',
    index=6,
    containing_service=None,
    input_type=_SUBSCRIBEQUEUESTATISTICSREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEINFO,
    serialized_options=_b('\332\222\003\r\n\013queue-stats'),
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeQueueEvents',
    full_name='yamcs.protobuf.commanding.QueueApi.SubscribeQueueEvents',
    index=7,
    containing_service=None,
    input_type=_SUBSCRIBEQUEUEEVENTSREQUEST,
    output_type=yamcs_dot_protobuf_dot_commanding_dot_commanding__pb2._COMMANDQUEUEEVENT,
    serialized_options=_b('\332\222\003\016\n\014queue-events'),
  ),
  _descriptor.MethodDescriptor(
    name='ListQueuedCommands',
    full_name='yamcs.protobuf.commanding.QueueApi.ListQueuedCommands',
    index=8,
    containing_service=None,
    input_type=_LISTQUEUEDCOMMANDSREQUEST,
    output_type=_LISTQUEUEDCOMMANDSRESPONSE,
    serialized_options=_b('\212\222\003\201\001\n>/api/processors/{instance}/{processor}/queues/{queue}/commandsZ?\n=/api/processors/{instance}/{processor}/queues/{queue}/entries'),
  ),
  _descriptor.MethodDescriptor(
    name='UpdateQueueEntry',
    full_name='yamcs.protobuf.commanding.QueueApi.UpdateQueueEntry',
    index=9,
    containing_service=None,
    input_type=_EDITQUEUEENTRYREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003K*D/api/processors/{instance}/{processor}/queues/{queue}/entries/{uuid}0\001:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='AcceptCommand',
    full_name='yamcs.protobuf.commanding.QueueApi.AcceptCommand',
    index=10,
    containing_service=None,
    input_type=_ACCEPTCOMMANDREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003Q\032O/api/processors/{instance}/{processor}/queues/{queue}/commands/{command}:accept'),
  ),
  _descriptor.MethodDescriptor(
    name='RejectCommand',
    full_name='yamcs.protobuf.commanding.QueueApi.RejectCommand',
    index=11,
    containing_service=None,
    input_type=_REJECTCOMMANDREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003Q\032O/api/processors/{instance}/{processor}/queues/{queue}/commands/{command}:reject'),
  ),
])
_sym_db.RegisterServiceDescriptor(_QUEUEAPI)

DESCRIPTOR.services_by_name['QueueApi'] = _QUEUEAPI

# @@protoc_insertion_point(module_scope)
