# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yamcs/protobuf/filetransfer/filetransfer.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from yamcs.api import annotations_pb2 as yamcs_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='yamcs/protobuf/filetransfer/filetransfer.proto',
  package='yamcs.protobuf.filetransfer',
  syntax='proto2',
  serialized_options=_b('\n\022org.yamcs.protobufB\021FileTransferProtoP\001'),
  serialized_pb=_b('\n.yamcs/protobuf/filetransfer/filetransfer.proto\x12\x1byamcs.protobuf.filetransfer\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1byamcs/api/annotations.proto\"@\n\rTransactionId\x12\x16\n\x0esequenceNumber\x18\x01 \x01(\r\x12\x17\n\x0finitiatorEntity\x18\x02 \x01(\x04\"3\n\x1fListFileTransferServicesRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\"j\n ListFileTransferServicesResponse\x12\x46\n\x08services\x18\x01 \x03(\x0b\x32\x34.yamcs.protobuf.filetransfer.FileTransferServiceInfo\"e\n\x18\x46ileTransferCapabilities\x12\x0e\n\x06upload\x18\x01 \x01(\x08\x12\x10\n\x08\x64ownload\x18\x02 \x01(\x08\x12\x13\n\x0breliability\x18\x03 \x01(\x08\x12\x12\n\nremotePath\x18\x04 \x01(\x08\"\x87\x02\n\x17\x46ileTransferServiceInfo\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12>\n\rlocalEntities\x18\x03 \x03(\x0b\x32\'.yamcs.protobuf.filetransfer.EntityInfo\x12?\n\x0eremoteEntities\x18\x04 \x03(\x0b\x32\'.yamcs.protobuf.filetransfer.EntityInfo\x12K\n\x0c\x63\x61pabilities\x18\x05 \x01(\x0b\x32\x35.yamcs.protobuf.filetransfer.FileTransferCapabilities\"&\n\nEntityInfo\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x04\"\xc9\x03\n\x0cTransferInfo\x12\n\n\x02id\x18\x01 \x01(\x04\x12-\n\tstartTime\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x05state\x18\x03 \x01(\x0e\x32*.yamcs.protobuf.filetransfer.TransferState\x12\x0e\n\x06\x62ucket\x18\x04 \x01(\t\x12\x12\n\nobjectName\x18\x05 \x01(\t\x12\x12\n\nremotePath\x18\x06 \x01(\t\x12\x41\n\tdirection\x18\x07 \x01(\x0e\x32..yamcs.protobuf.filetransfer.TransferDirection\x12\x11\n\ttotalSize\x18\x08 \x01(\x04\x12\x17\n\x0fsizeTransferred\x18\t \x01(\x04\x12\x10\n\x08reliable\x18\n \x01(\x08\x12\x15\n\rfailureReason\x18\x0b \x01(\t\x12\x41\n\rtransactionId\x18\x0c \x01(\x0b\x32*.yamcs.protobuf.filetransfer.TransactionId\x12\x30\n\x0c\x63reationTime\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8b\x04\n\x15\x43reateTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x08 \x01(\t\x12\x41\n\tdirection\x18\x02 \x01(\x0e\x32..yamcs.protobuf.filetransfer.TransferDirection\x12\x0e\n\x06\x62ucket\x18\x03 \x01(\t\x12\x12\n\nobjectName\x18\x04 \x01(\t\x12\x12\n\nremotePath\x18\x05 \x01(\t\x12[\n\x0f\x64ownloadOptions\x18\x06 \x01(\x0b\x32\x42.yamcs.protobuf.filetransfer.CreateTransferRequest.DownloadOptions\x12W\n\ruploadOptions\x18\x07 \x01(\x0b\x32@.yamcs.protobuf.filetransfer.CreateTransferRequest.UploadOptions\x12\x0e\n\x06source\x18\t \x01(\t\x12\x13\n\x0b\x64\x65stination\x18\n \x01(\t\x1a\x62\n\rUploadOptions\x12\x11\n\toverwrite\x18\x01 \x01(\x08\x12\x12\n\ncreatePath\x18\x02 \x01(\x08\x12\x10\n\x08reliable\x18\x03 \x01(\x08\x12\x18\n\x10\x63losureRequested\x18\x04 \x01(\x08\x1a\x11\n\x0f\x44ownloadOptions\"I\n\x14PauseTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x03 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"J\n\x15\x43\x61ncelTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x03 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"J\n\x15ResumeTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x03 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"=\n\x14ListTransfersRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t\"G\n\x12GetTransferRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x03 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\x03\"U\n\x15ListTransfersResponse\x12<\n\ttransfers\x18\x01 \x03(\x0b\x32).yamcs.protobuf.filetransfer.TransferInfo\"B\n\x19SubscribeTransfersRequest\x12\x10\n\x08instance\x18\x01 \x01(\t\x12\x13\n\x0bserviceName\x18\x02 \x01(\t*-\n\x11TransferDirection\x12\n\n\x06UPLOAD\x10\x01\x12\x0c\n\x08\x44OWNLOAD\x10\x02*_\n\rTransferState\x12\x0b\n\x07RUNNING\x10\x01\x12\n\n\x06PAUSED\x10\x02\x12\n\n\x06\x46\x41ILED\x10\x03\x12\r\n\tCOMPLETED\x10\x04\x12\n\n\x06QUEUED\x10\x05\x12\x0e\n\nCANCELLING\x10\x06\x32\xef\n\n\x0f\x46ileTransferApi\x12\xc4\x01\n\x18ListFileTransferServices\x12<.yamcs.protobuf.filetransfer.ListFileTransferServicesRequest\x1a=.yamcs.protobuf.filetransfer.ListFileTransferServicesResponse\"+\x8a\x92\x03\'\n%/api/filetransfer/{instance}/services\x12\xb2\x01\n\rListTransfers\x12\x31.yamcs.protobuf.filetransfer.ListTransfersRequest\x1a\x32.yamcs.protobuf.filetransfer.ListTransfersResponse\":\x8a\x92\x03\x36\n4/api/filetransfer/{instance}/{serviceName}/transfers\x12\xaa\x01\n\x0bGetTransfer\x12/.yamcs.protobuf.filetransfer.GetTransferRequest\x1a).yamcs.protobuf.filetransfer.TransferInfo\"?\x8a\x92\x03;\n9/api/filetransfer/{instance}/{serviceName}/transfers/{id}\x12\xae\x01\n\x0e\x43reateTransfer\x12\x32.yamcs.protobuf.filetransfer.CreateTransferRequest\x1a).yamcs.protobuf.filetransfer.TransferInfo\"=\x8a\x92\x03\x39\x1a\x34/api/filetransfer/{instance}/{serviceName}/transfers:\x01*\x12\xa1\x01\n\rPauseTransfer\x12\x31.yamcs.protobuf.filetransfer.PauseTransferRequest\x1a\x16.google.protobuf.Empty\"E\x8a\x92\x03\x41\x1a?/api/filetransfer/{instance}/{serviceName}/transfers/{id}:pause\x12\xa4\x01\n\x0e\x43\x61ncelTransfer\x12\x32.yamcs.protobuf.filetransfer.CancelTransferRequest\x1a\x16.google.protobuf.Empty\"F\x8a\x92\x03\x42\x1a@/api/filetransfer/{instance}/{serviceName}/transfers/{id}:cancel\x12\xa4\x01\n\x0eResumeTransfer\x12\x32.yamcs.protobuf.filetransfer.ResumeTransferRequest\x1a\x16.google.protobuf.Empty\"F\x8a\x92\x03\x42\x1a@/api/filetransfer/{instance}/{serviceName}/transfers/{id}:resume\x12\x8f\x01\n\x12SubscribeTransfers\x12\x36.yamcs.protobuf.filetransfer.SubscribeTransfersRequest\x1a).yamcs.protobuf.filetransfer.TransferInfo\"\x14\xda\x92\x03\x10\n\x0e\x66ile-transfers0\x01\x42)\n\x12org.yamcs.protobufB\x11\x46ileTransferProtoP\x01')
  ,
  dependencies=[google_dot_protobuf_dot_timestamp__pb2.DESCRIPTOR,google_dot_protobuf_dot_empty__pb2.DESCRIPTOR,yamcs_dot_api_dot_annotations__pb2.DESCRIPTOR,])

_TRANSFERDIRECTION = _descriptor.EnumDescriptor(
  name='TransferDirection',
  full_name='yamcs.protobuf.filetransfer.TransferDirection',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UPLOAD', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DOWNLOAD', index=1, number=2,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2310,
  serialized_end=2355,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERDIRECTION)

TransferDirection = enum_type_wrapper.EnumTypeWrapper(_TRANSFERDIRECTION)
_TRANSFERSTATE = _descriptor.EnumDescriptor(
  name='TransferState',
  full_name='yamcs.protobuf.filetransfer.TransferState',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='RUNNING', index=0, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAUSED', index=1, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FAILED', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='COMPLETED', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='QUEUED', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANCELLING', index=5, number=6,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=2357,
  serialized_end=2452,
)
_sym_db.RegisterEnumDescriptor(_TRANSFERSTATE)

TransferState = enum_type_wrapper.EnumTypeWrapper(_TRANSFERSTATE)
UPLOAD = 1
DOWNLOAD = 2
RUNNING = 1
PAUSED = 2
FAILED = 3
COMPLETED = 4
QUEUED = 5
CANCELLING = 6



_TRANSACTIONID = _descriptor.Descriptor(
  name='TransactionId',
  full_name='yamcs.protobuf.filetransfer.TransactionId',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='sequenceNumber', full_name='yamcs.protobuf.filetransfer.TransactionId.sequenceNumber', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='initiatorEntity', full_name='yamcs.protobuf.filetransfer.TransactionId.initiatorEntity', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=170,
  serialized_end=234,
)


_LISTFILETRANSFERSERVICESREQUEST = _descriptor.Descriptor(
  name='ListFileTransferServicesRequest',
  full_name='yamcs.protobuf.filetransfer.ListFileTransferServicesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.ListFileTransferServicesRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=236,
  serialized_end=287,
)


_LISTFILETRANSFERSERVICESRESPONSE = _descriptor.Descriptor(
  name='ListFileTransferServicesResponse',
  full_name='yamcs.protobuf.filetransfer.ListFileTransferServicesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='services', full_name='yamcs.protobuf.filetransfer.ListFileTransferServicesResponse.services', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=289,
  serialized_end=395,
)


_FILETRANSFERCAPABILITIES = _descriptor.Descriptor(
  name='FileTransferCapabilities',
  full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='upload', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.upload', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='download', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.download', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reliability', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.reliability', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remotePath', full_name='yamcs.protobuf.filetransfer.FileTransferCapabilities.remotePath', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=397,
  serialized_end=498,
)


_FILETRANSFERSERVICEINFO = _descriptor.Descriptor(
  name='FileTransferServiceInfo',
  full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='localEntities', full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo.localEntities', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remoteEntities', full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo.remoteEntities', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='capabilities', full_name='yamcs.protobuf.filetransfer.FileTransferServiceInfo.capabilities', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=501,
  serialized_end=764,
)


_ENTITYINFO = _descriptor.Descriptor(
  name='EntityInfo',
  full_name='yamcs.protobuf.filetransfer.EntityInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='yamcs.protobuf.filetransfer.EntityInfo.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.EntityInfo.id', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=766,
  serialized_end=804,
)


_TRANSFERINFO = _descriptor.Descriptor(
  name='TransferInfo',
  full_name='yamcs.protobuf.filetransfer.TransferInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.TransferInfo.id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='startTime', full_name='yamcs.protobuf.filetransfer.TransferInfo.startTime', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='state', full_name='yamcs.protobuf.filetransfer.TransferInfo.state', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='yamcs.protobuf.filetransfer.TransferInfo.bucket', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectName', full_name='yamcs.protobuf.filetransfer.TransferInfo.objectName', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remotePath', full_name='yamcs.protobuf.filetransfer.TransferInfo.remotePath', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='yamcs.protobuf.filetransfer.TransferInfo.direction', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='totalSize', full_name='yamcs.protobuf.filetransfer.TransferInfo.totalSize', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sizeTransferred', full_name='yamcs.protobuf.filetransfer.TransferInfo.sizeTransferred', index=8,
      number=9, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reliable', full_name='yamcs.protobuf.filetransfer.TransferInfo.reliable', index=9,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='failureReason', full_name='yamcs.protobuf.filetransfer.TransferInfo.failureReason', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='transactionId', full_name='yamcs.protobuf.filetransfer.TransferInfo.transactionId', index=11,
      number=12, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='creationTime', full_name='yamcs.protobuf.filetransfer.TransferInfo.creationTime', index=12,
      number=13, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=807,
  serialized_end=1264,
)


_CREATETRANSFERREQUEST_UPLOADOPTIONS = _descriptor.Descriptor(
  name='UploadOptions',
  full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.UploadOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='overwrite', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.UploadOptions.overwrite', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='createPath', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.UploadOptions.createPath', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reliable', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.UploadOptions.reliable', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='closureRequested', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.UploadOptions.closureRequested', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1673,
  serialized_end=1771,
)

_CREATETRANSFERREQUEST_DOWNLOADOPTIONS = _descriptor.Descriptor(
  name='DownloadOptions',
  full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.DownloadOptions',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1773,
  serialized_end=1790,
)

_CREATETRANSFERREQUEST = _descriptor.Descriptor(
  name='CreateTransferRequest',
  full_name='yamcs.protobuf.filetransfer.CreateTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.serviceName', index=1,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='direction', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.direction', index=2,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=1,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='bucket', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.bucket', index=3,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objectName', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.objectName', index=4,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remotePath', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.remotePath', index=5,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='downloadOptions', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.downloadOptions', index=6,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='uploadOptions', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.uploadOptions', index=7,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='source', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.source', index=8,
      number=9, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination', full_name='yamcs.protobuf.filetransfer.CreateTransferRequest.destination', index=9,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_CREATETRANSFERREQUEST_UPLOADOPTIONS, _CREATETRANSFERREQUEST_DOWNLOADOPTIONS, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1267,
  serialized_end=1790,
)


_PAUSETRANSFERREQUEST = _descriptor.Descriptor(
  name='PauseTransferRequest',
  full_name='yamcs.protobuf.filetransfer.PauseTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.PauseTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.PauseTransferRequest.serviceName', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.PauseTransferRequest.id', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1792,
  serialized_end=1865,
)


_CANCELTRANSFERREQUEST = _descriptor.Descriptor(
  name='CancelTransferRequest',
  full_name='yamcs.protobuf.filetransfer.CancelTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.CancelTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.CancelTransferRequest.serviceName', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.CancelTransferRequest.id', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1867,
  serialized_end=1941,
)


_RESUMETRANSFERREQUEST = _descriptor.Descriptor(
  name='ResumeTransferRequest',
  full_name='yamcs.protobuf.filetransfer.ResumeTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.ResumeTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.ResumeTransferRequest.serviceName', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.ResumeTransferRequest.id', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1943,
  serialized_end=2017,
)


_LISTTRANSFERSREQUEST = _descriptor.Descriptor(
  name='ListTransfersRequest',
  full_name='yamcs.protobuf.filetransfer.ListTransfersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.ListTransfersRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2019,
  serialized_end=2080,
)


_GETTRANSFERREQUEST = _descriptor.Descriptor(
  name='GetTransferRequest',
  full_name='yamcs.protobuf.filetransfer.GetTransferRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.GetTransferRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.GetTransferRequest.serviceName', index=1,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='yamcs.protobuf.filetransfer.GetTransferRequest.id', index=2,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2082,
  serialized_end=2153,
)


_LISTTRANSFERSRESPONSE = _descriptor.Descriptor(
  name='ListTransfersResponse',
  full_name='yamcs.protobuf.filetransfer.ListTransfersResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='transfers', full_name='yamcs.protobuf.filetransfer.ListTransfersResponse.transfers', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2155,
  serialized_end=2240,
)


_SUBSCRIBETRANSFERSREQUEST = _descriptor.Descriptor(
  name='SubscribeTransfersRequest',
  full_name='yamcs.protobuf.filetransfer.SubscribeTransfersRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='instance', full_name='yamcs.protobuf.filetransfer.SubscribeTransfersRequest.instance', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='serviceName', full_name='yamcs.protobuf.filetransfer.SubscribeTransfersRequest.serviceName', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2242,
  serialized_end=2308,
)

_LISTFILETRANSFERSERVICESRESPONSE.fields_by_name['services'].message_type = _FILETRANSFERSERVICEINFO
_FILETRANSFERSERVICEINFO.fields_by_name['localEntities'].message_type = _ENTITYINFO
_FILETRANSFERSERVICEINFO.fields_by_name['remoteEntities'].message_type = _ENTITYINFO
_FILETRANSFERSERVICEINFO.fields_by_name['capabilities'].message_type = _FILETRANSFERCAPABILITIES
_TRANSFERINFO.fields_by_name['startTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_TRANSFERINFO.fields_by_name['state'].enum_type = _TRANSFERSTATE
_TRANSFERINFO.fields_by_name['direction'].enum_type = _TRANSFERDIRECTION
_TRANSFERINFO.fields_by_name['transactionId'].message_type = _TRANSACTIONID
_TRANSFERINFO.fields_by_name['creationTime'].message_type = google_dot_protobuf_dot_timestamp__pb2._TIMESTAMP
_CREATETRANSFERREQUEST_UPLOADOPTIONS.containing_type = _CREATETRANSFERREQUEST
_CREATETRANSFERREQUEST_DOWNLOADOPTIONS.containing_type = _CREATETRANSFERREQUEST
_CREATETRANSFERREQUEST.fields_by_name['direction'].enum_type = _TRANSFERDIRECTION
_CREATETRANSFERREQUEST.fields_by_name['downloadOptions'].message_type = _CREATETRANSFERREQUEST_DOWNLOADOPTIONS
_CREATETRANSFERREQUEST.fields_by_name['uploadOptions'].message_type = _CREATETRANSFERREQUEST_UPLOADOPTIONS
_LISTTRANSFERSRESPONSE.fields_by_name['transfers'].message_type = _TRANSFERINFO
DESCRIPTOR.message_types_by_name['TransactionId'] = _TRANSACTIONID
DESCRIPTOR.message_types_by_name['ListFileTransferServicesRequest'] = _LISTFILETRANSFERSERVICESREQUEST
DESCRIPTOR.message_types_by_name['ListFileTransferServicesResponse'] = _LISTFILETRANSFERSERVICESRESPONSE
DESCRIPTOR.message_types_by_name['FileTransferCapabilities'] = _FILETRANSFERCAPABILITIES
DESCRIPTOR.message_types_by_name['FileTransferServiceInfo'] = _FILETRANSFERSERVICEINFO
DESCRIPTOR.message_types_by_name['EntityInfo'] = _ENTITYINFO
DESCRIPTOR.message_types_by_name['TransferInfo'] = _TRANSFERINFO
DESCRIPTOR.message_types_by_name['CreateTransferRequest'] = _CREATETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['PauseTransferRequest'] = _PAUSETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['CancelTransferRequest'] = _CANCELTRANSFERREQUEST
DESCRIPTOR.message_types_by_name['ResumeTransferRequest'] = _RESUMETRANSFERREQUEST
DESCRIPTOR.message_types_by_name['ListTransfersRequest'] = _LISTTRANSFERSREQUEST
DESCRIPTOR.message_types_by_name['GetTransferRequest'] = _GETTRANSFERREQUEST
DESCRIPTOR.message_types_by_name['ListTransfersResponse'] = _LISTTRANSFERSRESPONSE
DESCRIPTOR.message_types_by_name['SubscribeTransfersRequest'] = _SUBSCRIBETRANSFERSREQUEST
DESCRIPTOR.enum_types_by_name['TransferDirection'] = _TRANSFERDIRECTION
DESCRIPTOR.enum_types_by_name['TransferState'] = _TRANSFERSTATE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

TransactionId = _reflection.GeneratedProtocolMessageType('TransactionId', (_message.Message,), dict(
  DESCRIPTOR = _TRANSACTIONID,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.TransactionId)
  ))
_sym_db.RegisterMessage(TransactionId)

ListFileTransferServicesRequest = _reflection.GeneratedProtocolMessageType('ListFileTransferServicesRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTFILETRANSFERSERVICESREQUEST,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ListFileTransferServicesRequest)
  ))
_sym_db.RegisterMessage(ListFileTransferServicesRequest)

ListFileTransferServicesResponse = _reflection.GeneratedProtocolMessageType('ListFileTransferServicesResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTFILETRANSFERSERVICESRESPONSE,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ListFileTransferServicesResponse)
  ))
_sym_db.RegisterMessage(ListFileTransferServicesResponse)

FileTransferCapabilities = _reflection.GeneratedProtocolMessageType('FileTransferCapabilities', (_message.Message,), dict(
  DESCRIPTOR = _FILETRANSFERCAPABILITIES,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.FileTransferCapabilities)
  ))
_sym_db.RegisterMessage(FileTransferCapabilities)

FileTransferServiceInfo = _reflection.GeneratedProtocolMessageType('FileTransferServiceInfo', (_message.Message,), dict(
  DESCRIPTOR = _FILETRANSFERSERVICEINFO,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.FileTransferServiceInfo)
  ))
_sym_db.RegisterMessage(FileTransferServiceInfo)

EntityInfo = _reflection.GeneratedProtocolMessageType('EntityInfo', (_message.Message,), dict(
  DESCRIPTOR = _ENTITYINFO,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.EntityInfo)
  ))
_sym_db.RegisterMessage(EntityInfo)

TransferInfo = _reflection.GeneratedProtocolMessageType('TransferInfo', (_message.Message,), dict(
  DESCRIPTOR = _TRANSFERINFO,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.TransferInfo)
  ))
_sym_db.RegisterMessage(TransferInfo)

CreateTransferRequest = _reflection.GeneratedProtocolMessageType('CreateTransferRequest', (_message.Message,), dict(

  UploadOptions = _reflection.GeneratedProtocolMessageType('UploadOptions', (_message.Message,), dict(
    DESCRIPTOR = _CREATETRANSFERREQUEST_UPLOADOPTIONS,
    __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.CreateTransferRequest.UploadOptions)
    ))
  ,

  DownloadOptions = _reflection.GeneratedProtocolMessageType('DownloadOptions', (_message.Message,), dict(
    DESCRIPTOR = _CREATETRANSFERREQUEST_DOWNLOADOPTIONS,
    __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
    # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.CreateTransferRequest.DownloadOptions)
    ))
  ,
  DESCRIPTOR = _CREATETRANSFERREQUEST,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.CreateTransferRequest)
  ))
_sym_db.RegisterMessage(CreateTransferRequest)
_sym_db.RegisterMessage(CreateTransferRequest.UploadOptions)
_sym_db.RegisterMessage(CreateTransferRequest.DownloadOptions)

PauseTransferRequest = _reflection.GeneratedProtocolMessageType('PauseTransferRequest', (_message.Message,), dict(
  DESCRIPTOR = _PAUSETRANSFERREQUEST,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.PauseTransferRequest)
  ))
_sym_db.RegisterMessage(PauseTransferRequest)

CancelTransferRequest = _reflection.GeneratedProtocolMessageType('CancelTransferRequest', (_message.Message,), dict(
  DESCRIPTOR = _CANCELTRANSFERREQUEST,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.CancelTransferRequest)
  ))
_sym_db.RegisterMessage(CancelTransferRequest)

ResumeTransferRequest = _reflection.GeneratedProtocolMessageType('ResumeTransferRequest', (_message.Message,), dict(
  DESCRIPTOR = _RESUMETRANSFERREQUEST,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ResumeTransferRequest)
  ))
_sym_db.RegisterMessage(ResumeTransferRequest)

ListTransfersRequest = _reflection.GeneratedProtocolMessageType('ListTransfersRequest', (_message.Message,), dict(
  DESCRIPTOR = _LISTTRANSFERSREQUEST,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ListTransfersRequest)
  ))
_sym_db.RegisterMessage(ListTransfersRequest)

GetTransferRequest = _reflection.GeneratedProtocolMessageType('GetTransferRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETTRANSFERREQUEST,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.GetTransferRequest)
  ))
_sym_db.RegisterMessage(GetTransferRequest)

ListTransfersResponse = _reflection.GeneratedProtocolMessageType('ListTransfersResponse', (_message.Message,), dict(
  DESCRIPTOR = _LISTTRANSFERSRESPONSE,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.ListTransfersResponse)
  ))
_sym_db.RegisterMessage(ListTransfersResponse)

SubscribeTransfersRequest = _reflection.GeneratedProtocolMessageType('SubscribeTransfersRequest', (_message.Message,), dict(
  DESCRIPTOR = _SUBSCRIBETRANSFERSREQUEST,
  __module__ = 'yamcs.protobuf.filetransfer.filetransfer_pb2'
  # @@protoc_insertion_point(class_scope:yamcs.protobuf.filetransfer.SubscribeTransfersRequest)
  ))
_sym_db.RegisterMessage(SubscribeTransfersRequest)


DESCRIPTOR._options = None

_FILETRANSFERAPI = _descriptor.ServiceDescriptor(
  name='FileTransferApi',
  full_name='yamcs.protobuf.filetransfer.FileTransferApi',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=2455,
  serialized_end=3846,
  methods=[
  _descriptor.MethodDescriptor(
    name='ListFileTransferServices',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.ListFileTransferServices',
    index=0,
    containing_service=None,
    input_type=_LISTFILETRANSFERSERVICESREQUEST,
    output_type=_LISTFILETRANSFERSERVICESRESPONSE,
    serialized_options=_b('\212\222\003\'\n%/api/filetransfer/{instance}/services'),
  ),
  _descriptor.MethodDescriptor(
    name='ListTransfers',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.ListTransfers',
    index=1,
    containing_service=None,
    input_type=_LISTTRANSFERSREQUEST,
    output_type=_LISTTRANSFERSRESPONSE,
    serialized_options=_b('\212\222\0036\n4/api/filetransfer/{instance}/{serviceName}/transfers'),
  ),
  _descriptor.MethodDescriptor(
    name='GetTransfer',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.GetTransfer',
    index=2,
    containing_service=None,
    input_type=_GETTRANSFERREQUEST,
    output_type=_TRANSFERINFO,
    serialized_options=_b('\212\222\003;\n9/api/filetransfer/{instance}/{serviceName}/transfers/{id}'),
  ),
  _descriptor.MethodDescriptor(
    name='CreateTransfer',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.CreateTransfer',
    index=3,
    containing_service=None,
    input_type=_CREATETRANSFERREQUEST,
    output_type=_TRANSFERINFO,
    serialized_options=_b('\212\222\0039\0324/api/filetransfer/{instance}/{serviceName}/transfers:\001*'),
  ),
  _descriptor.MethodDescriptor(
    name='PauseTransfer',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.PauseTransfer',
    index=4,
    containing_service=None,
    input_type=_PAUSETRANSFERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003A\032?/api/filetransfer/{instance}/{serviceName}/transfers/{id}:pause'),
  ),
  _descriptor.MethodDescriptor(
    name='CancelTransfer',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.CancelTransfer',
    index=5,
    containing_service=None,
    input_type=_CANCELTRANSFERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003B\032@/api/filetransfer/{instance}/{serviceName}/transfers/{id}:cancel'),
  ),
  _descriptor.MethodDescriptor(
    name='ResumeTransfer',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.ResumeTransfer',
    index=6,
    containing_service=None,
    input_type=_RESUMETRANSFERREQUEST,
    output_type=google_dot_protobuf_dot_empty__pb2._EMPTY,
    serialized_options=_b('\212\222\003B\032@/api/filetransfer/{instance}/{serviceName}/transfers/{id}:resume'),
  ),
  _descriptor.MethodDescriptor(
    name='SubscribeTransfers',
    full_name='yamcs.protobuf.filetransfer.FileTransferApi.SubscribeTransfers',
    index=7,
    containing_service=None,
    input_type=_SUBSCRIBETRANSFERSREQUEST,
    output_type=_TRANSFERINFO,
    serialized_options=_b('\332\222\003\020\n\016file-transfers'),
  ),
])
_sym_db.RegisterServiceDescriptor(_FILETRANSFERAPI)

DESCRIPTOR.services_by_name['FileTransferApi'] = _FILETRANSFERAPI

# @@protoc_insertion_point(module_scope)
